@@ -44,6 +44,9 @@ found in the LICENSE file.
 #include <QWebEngineUrlScheme>
 #include <QQuickWindow>
 
+#include <QMainWindow>
+#include <QTimer>
+
 namespace
 {
   void outputImportantQtMessage(QtMsgType type, const QMessageLogContext&, const QString& msg)
@@ -104,7 +107,7 @@ namespace
     // Manage Qt options as array of pairs, consisting of argument name and argument value requirement.
     // Qt command-line options: https://doc.qt.io/qt-6/qguiapplication.html#supported-command-line-options
 
-    std::array<std::pair<std::string, bool>, 12> qtOptions {{
+    std::array<std::pair<std::string, bool>, 13> qtOptions {{
       { "platform", true },
       { "platformpluginpath", true },
       { "platformtheme", true },
@@ -116,7 +119,8 @@ namespace
       { "reverse", false },
       { "session", true },
       { "display", true },
-      { "geometry", true }
+      { "geometry", true },
+      { "style", true }
     }};
 
     for (const auto& qtOption : qtOptions)
@@ -170,7 +174,7 @@ namespace mitk
   const QString BaseApplication::ARG_XARGS = "xargs";
   const QString BaseApplication::ARG_LOG_QT_MESSAGES = "Qt.logMessages";
   const QString BaseApplication::ARG_SEGMENTATION_LABELSET_PRESET = "Segmentation.labelSetPreset";
-  const QString BaseApplication::ARG_SEGMENTATION_LABEL_SUGGESTIONS = "Segmentation.labelSuggestions";
+  const QString BaseApplication::ARG_FULL_SCREEN_MODE = "MITK.fullscreen";
 
   const QString BaseApplication::PROP_APPLICATION = "blueberry.application";
   const QString BaseApplication::PROP_FORCE_PLUGIN_INSTALL = BaseApplication::ARG_FORCE_PLUGIN_INSTALL;
@@ -221,6 +225,7 @@ namespace mitk
     SplashCloserCallback *m_SplashscreenClosingCallback;
 
     bool m_LogQtMessages;
+    bool m_FullScreenMode;
 
     QStringList m_PreloadLibs;
     QString m_ProvFile;
@@ -236,7 +241,8 @@ namespace mitk
         m_SafeMode(true),
         m_Splashscreen(nullptr),
         m_SplashscreenClosingCallback(nullptr),
-        m_LogQtMessages(false)
+        m_LogQtMessages(false),
+        m_FullScreenMode(false)
     {
 #ifdef Q_OS_MAC
       /* On macOS the process serial number is passed as an command line argument (-psn_<NUMBER>)
@@ -285,6 +291,12 @@ namespace mitk
         return;
       }
 
+      if (ARG_FULL_SCREEN_MODE.toStdString() == name)
+      {
+        m_FullScreenMode = true;
+        return;
+      }
+
       auto fwKey = QString::fromStdString(name);
 
       // Translate some keys to proper framework properties
@@ -511,6 +523,19 @@ namespace mitk
     return d->m_SafeMode;
   }
 
+  void BaseApplication::setFullScreenMode(bool fullscreenMode)
+  {
+    if (nullptr != qApp)
+      return;
+
+    d->m_FullScreenMode = fullscreenMode;
+  }
+
+  bool BaseApplication::getFullScreenMode() const
+  {
+    return d->m_FullScreenMode;
+  }
+
   void BaseApplication::setPreloadLibraries(const QStringList &libraryBaseNames)
   {
     d->m_PreloadLibs = libraryBaseNames;
@@ -592,7 +617,7 @@ namespace mitk
     {
       // If not set explicitly otherwise, prefer xcb as platform on Linux, as we had issues
       // with wayland in combination with VTK and GLEW. Note that the shell scripts for
-      // excutables in our installers also set the platform to xcb.
+      // executables in our installers also set the platform to xcb.
       if (qEnvironmentVariableIsEmpty("QT_QPA_PLATFORM"))
         qputenv("QT_QPA_PLATFORM", "xcb");
     }
@@ -601,7 +626,12 @@ namespace mitk
 #endif
 
     // Prevent conflicts between native OpenGL applications and QWebEngine
-    QQuickWindow::setGraphicsApi(QSGRendererInterface::Software);
+    if (qEnvironmentVariableIsEmpty("QSG_RHI_BACKEND"))
+#if (QT_VERSION >= QT_VERSION_CHECK(6, 7, 0))
+      QQuickWindow::setGraphicsApi(QSGRendererInterface::OpenGL);
+#else
+      QQuickWindow::setGraphicsApi(QSGRendererInterface::Software);
+#endif
 
     // If parameters have been set before, we have to store them to hand them
     // through to the application
@@ -899,9 +929,10 @@ namespace mitk
     labelSetPresetOption.argument("<filename>").binding(ARG_SEGMENTATION_LABELSET_PRESET.toStdString());
     options.addOption(labelSetPresetOption);
 
-    Poco::Util::Option labelSuggestionsOption(ARG_SEGMENTATION_LABEL_SUGGESTIONS.toStdString(), "", "use this list of predefined suggestions for segmentation labels");
-    labelSuggestionsOption.argument("<filename>").binding(ARG_SEGMENTATION_LABEL_SUGGESTIONS.toStdString());
-    options.addOption(labelSuggestionsOption);
+    Poco::Util::Option fullscreenOption(ARG_FULL_SCREEN_MODE.toStdString(), "", "use this flag to start the application in full screen mode w/o window frame");
+    fullscreenOption.callback(Poco::Util::OptionCallback<Impl>(d, &Impl::handleBooleanOption));
+    options.addOption(fullscreenOption);
+
 
     // Make Poco aware of QGuiApplication command-line options, even though they are only parsed by
     // Qt. Otherwise, Poco would throw exceptions for unknown options.
