@@ -14,13 +14,8 @@ found in the LICENSE file.
 #define mitkBoundingShapeVtkMapper3D_h
 
 #include <MitkBoundingShapeExports.h>
-
 #include <mitkVtkMapper.h>
 
-#include <vtkPropAssembly.h>
-#include <vtkSmartPointer.h>
-#include <vtkSphereSource.h>
-
 namespace mitk
 {
   class MITKBOUNDINGSHAPE_EXPORT BoundingShapeVtkMapper3D : public VtkMapper
