@@ -23,33 +23,27 @@ namespace mitk
 {
   class BaseRenderer;
 
-  //##Documentation
-  //## @brief Baseclass for renderer slice-/camera-control
-  //##
-  //## Tells the render (subclass of BaseRenderer) which slice (subclass
-  //## SliceNavigationController) or from which direction (subclass
-  //## CameraController) it has to render. Contains two Stepper for stepping
-  //## through the slices or through different camera views (e.g., for the
-  //## creation of a movie around the data), respectively, and through time, if
-  //## there is 3D+t data.
-  //## @note not yet implemented
-  //## @ingroup NavigationControl
+  /**
+   * \brief Baseclass for renderer slice-/camera-/time-control
+   *
+   *        Tells the renderer (subclass of BaseRenderer) which slice (SliceNavigationController),
+   *        which direction (CameraController) or which time (TimeNavigationController) it has to render.
+   *        Contains a Stepper for stepping through the slices, through different
+   *        camera views (e.g., for the creation of a movie around the data)
+   *        and through time, if there is 3D+t data.
+   */
   class MITKCORE_EXPORT BaseController : public OperationActor, public itk::Object
   {
   public:
-    /** Standard class typedefs. */
+
     mitkClassMacroItkParent(BaseController, OperationActor);
     itkFactorylessNewMacro(Self);
 
-    //##Documentation
-    //## @brief Get the Stepper through the slices
-    Stepper *GetSlice();
-    const Stepper* GetSlice() const;
-
-    //##Documentation
-    //## @brief Get the Stepper through the time
-    Stepper *GetTime();
-    const Stepper* GetTime() const;
+    /**
+    * \brief Get the stepper through the corresponding dimension.
+    */
+    Stepper* GetStepper();
+    const Stepper* GetStepper() const;
 
   protected:
     /**
@@ -64,10 +58,8 @@ namespace mitk
 
     void ExecuteOperation(Operation *) override;
 
-    //## @brief Stepper through the time
-    Stepper::Pointer m_Time;
-    //## @brief Stepper through the slices
-    Stepper::Pointer m_Slice;
+    //## @brief Stepper through the different dimensions
+    Stepper::Pointer m_Stepper;
 
     unsigned long m_LastUpdateTime;
   };
