@@ -64,6 +64,9 @@ namespace mitk
 
     std::string GetValueAsString() const override;
 
+    bool ToJSON(nlohmann::json& j) const override;
+    bool FromJSON(const nlohmann::json& j) override;
+
     using BaseProperty::operator=;
 
   private:
