@@ -54,11 +54,11 @@ private:
   ::mitk::Message1<type1> m_##msgHandleObject##Message;                                                                \
                                                                                                                        \
 public:                                                                                                                \
-  void Add##msgHandleObject##Listener(const ::mitk::MessageAbstractDelegate1<type1> &delegate)                         \
+  void Add##msgHandleObject##Listener(const ::mitk::MessageAbstractDelegate1<type1> &delegate) const                   \
   {                                                                                                                    \
     m_##msgHandleObject##Message += delegate;                                                                          \
   }                                                                                                                    \
-  void Remove##msgHandleObject##Listener(const ::mitk::MessageAbstractDelegate1<type1> &delegate)                      \
+  void Remove##msgHandleObject##Listener(const ::mitk::MessageAbstractDelegate1<type1> &delegate) const                \
   {                                                                                                                    \
     m_##msgHandleObject##Message -= delegate;                                                                          \
   }
@@ -589,7 +589,7 @@ namespace mitk
 
 /* Here is an example how to use the macros and templates:
 *
-* // An object to be send around
+* // An object to be sent around
 * class Law
 * {
 *   private:
