@@ -365,7 +365,7 @@ namespace mitk
     /**
     * \brief Calculate two points where another plane intersects the border of this plane
     *
-    * \return number of intersection points (0..2). First interection point (if existing)
+    * \return number of intersection points (0..2). First intersection point (if existing)
     * is returned in \a lineFrom, second in \a lineTo.
     */
     unsigned int IntersectWithPlane2D(const PlaneGeometry *plane, Point2D &lineFrom, Point2D &lineTo) const;
@@ -553,8 +553,6 @@ namespace mitk
     const BaseGeometry *GetReferenceGeometry() const;
     bool HasReferenceGeometry() const;
 
-    static std::vector< int > CalculateDominantAxes(mitk::AffineTransform3D::MatrixType::InternalMatrixType& rotation_matrix);
-
   protected:
     PlaneGeometry();
 
