@@ -33,11 +33,20 @@ bool mitk::NodePredicateDimension::CheckNode(const mitk::DataNode *node) const
   if (node == nullptr)
     throw std::invalid_argument("NodePredicateDimension: invalid node");
 
-  auto *image = dynamic_cast<mitk::Image *>(node->GetData());
+  const auto data = node->GetData();
+  if (nullptr == data)
+    return false;
+
+  const auto *image = dynamic_cast<mitk::Image *>(data);
   if (image != nullptr)
   {
     return (image->GetDimension() == m_Dimension && image->GetPixelType().GetNumberOfComponents() == m_PixelComponents);
   }
+  else if (auto timeGeometry = data->GetTimeGeometry(); nullptr!=timeGeometry && m_PixelComponents == 1)
+  { //node data is not of type image, but as pixel component is default,we can fall back on
+    //only checking the dimension via the time geometry information of data.
+    return m_Dimension == DetermineImageDimensionsFromTimeGeometry(timeGeometry).size();
+  }
 
   return false;
 }
