@@ -1,21 +1,17 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "mitkVtkLoggingAdapter.h"
-#include "mitkLogMacros.h"
+#include "mitkLog.h"
 #include <vtkObjectFactory.h>
 
 namespace mitk
@@ -25,12 +21,12 @@ namespace mitk
 
 void mitk::VtkLoggingAdapter::Initialize()
 {
-  mitk::VtkLoggingAdapter* vtklog = mitk::VtkLoggingAdapter::New();
+  mitk::VtkLoggingAdapter *vtklog = mitk::VtkLoggingAdapter::New();
   vtkOutputWindow::SetInstance(vtklog);
   vtklog->Delete();
 }
 
-void mitk::VtkLoggingAdapter::DisplayText(const char* t)
+void mitk::VtkLoggingAdapter::DisplayText(const char *t)
 {
   MITK_INFO("VtkText") << t;
 }
