@@ -13,8 +13,10 @@ found in the LICENSE file.
 
 #include "mitkTestDICOMLoading.h"
 #include "mitkDICOMIOMetaInformationPropertyConstants.h"
+#include "mitkIOMetaInformationPropertyConstants.h"
 #include "mitkDICOMProperty.h"
 #include "mitkArbitraryTimeGeometry.h"
+#include "mitkDICOMReaderConfigurator.h"
 
 #include <stack>
 
@@ -73,7 +75,7 @@ mitk::TestDICOMLoading
 
   ImageList result;
 
-  ClassicDICOMSeriesReader::Pointer reader = this->BuildDICOMReader();
+  DICOMFileReader::Pointer reader = this->BuildDICOMReader();
   reader->SetTagLookupTableToPropertyFunctor(mitk::GetDICOMPropertyForDICOMValuesFunctor);
   reader->SetInputFiles( files );
   reader->AnalyzeInputFiles();
@@ -90,12 +92,20 @@ mitk::TestDICOMLoading
   return result;
 }
 
-mitk::ClassicDICOMSeriesReader::Pointer
+mitk::DICOMFileReader::Pointer
 mitk::TestDICOMLoading
 ::BuildDICOMReader()
 {
-  ClassicDICOMSeriesReader::Pointer reader = ClassicDICOMSeriesReader::New();
-  reader->SetFixTiltByShearing(true);
+  DICOMFileReader::Pointer reader;
+
+  std::string xmlDescription = DICOMReaderConfigurator::GetConfigStringFromModuleResource("configurations/3DnT/1_default_config.xml");
+
+  if (!xmlDescription.empty())
+  {
+    DICOMReaderConfigurator::Pointer configurator = DICOMReaderConfigurator::New();
+    reader = configurator->CreateFromUTF8ConfigString(xmlDescription);
+  }
+
   return reader;
 }
 
@@ -125,7 +135,7 @@ mitk::Image::Pointer
 mitk::TestDICOMLoading
 ::DecorateVerifyCachedImage( const StringList& files, mitk::Image::Pointer cachedImage )
 {
-  ClassicDICOMSeriesReader::Pointer reader = this->BuildDICOMReader();
+  auto reader = this->BuildDICOMReader();
   reader->SetTagLookupTableToPropertyFunctor(mitk::GetDICOMPropertyForDICOMValuesFunctor);
   reader->SetInputFiles( files );
   reader->AnalyzeInputFiles(); // This just creates a "tag cache and a nice DICOMImageBlockDescriptor.
@@ -287,6 +297,7 @@ mitk::TestDICOMLoading::DumpImageInformation( const Image* image )
   AddPropertyToDump(mitk::DICOMIOMetaInformationPropertyConstants::READER_3D_plus_t(), image, result);
   AddPropertyToDump(mitk::DICOMIOMetaInformationPropertyConstants::READER_DCMTK(), image, result);
   AddPropertyToDump(mitk::DICOMIOMetaInformationPropertyConstants::READER_GDCM(), image, result);
+  AddPropertyToDump(mitk::IOMetaInformationPropertyConstants::VOLUME_SPLIT_REASON(), image, result);
 
   ResetUserLocale();
 
@@ -489,6 +500,11 @@ mitk::TestDICOMLoading::CompareImageInformationDumps( const std::string& referen
         bool thisTestResult = CompareJSON(refValue, testValue);
         testResult &= thisTestResult;
       }
+      else if (refKey == mitk::PropertyKeyPathToPropertyName(mitk::IOMetaInformationPropertyConstants::VOLUME_SPLIT_REASON()))
+      {
+        bool thisTestResult = CompareJSON(refValue, testValue);
+        testResult &= thisTestResult;
+      }
       else
       {
         bool thisTestResult = CompareSpacedValueFields(refValue, testValue);
