@@ -12,7 +12,7 @@ found in the LICENSE file.
 
 #include "mitkMultiLabelSegmentationIO.h"
 #include "mitkBasePropertySerializer.h"
-#include "mitkIOMimeTypes.h"
+#include "mitkMultilabelIOMimeTypes.h"
 #include "mitkImageAccessByItk.h"
 #include "mitkMultiLabelIOHelper.h"
 #include "mitkLabelSetImageConverter.h"
@@ -38,12 +38,12 @@ namespace mitk
   const constexpr char* const MULTILABEL_SEGMENTATION_MODALITY_KEY = "modality";
   const constexpr char* const MULTILABEL_SEGMENTATION_MODALITY_VALUE = "org.mitk.multilabel.segmentation";
   const constexpr char* const MULTILABEL_SEGMENTATION_VERSION_KEY = "org.mitk.multilabel.segmentation.version";
-  const constexpr int MULTILABEL_SEGMENTATION_VERSION_VALUE = 1;
+  const constexpr int MULTILABEL_SEGMENTATION_VERSION_VALUE = 4;
   const constexpr char* const MULTILABEL_SEGMENTATION_LABELS_INFO_KEY = "org.mitk.multilabel.segmentation.labelgroups";
   const constexpr char* const MULTILABEL_SEGMENTATION_UNLABELEDLABEL_LOCK_KEY = "org.mitk.multilabel.segmentation.unlabeledlabellock";
 
   MultiLabelSegmentationIO::MultiLabelSegmentationIO()
-    : AbstractFileIO(LabelSetImage::GetStaticNameOfClass(), IOMimeTypes::NRRD_MIMETYPE(), "MITK Multilabel Segmentation")
+    : AbstractFileIO(MultiLabelSegmentation::GetStaticNameOfClass(), MitkMultilabelIOMimeTypes::MULTILABEL_SEGMENTATION_MIMETYPE(), "MITK Multilabel Segmentation")
   {
     this->InitializeDefaultMetaDataKeys();
     AbstractFileWriter::SetRanking(10);
@@ -55,7 +55,7 @@ namespace mitk
   {
     if (AbstractFileIO::GetWriterConfidenceLevel() == Unsupported)
       return Unsupported;
-    const auto *input = static_cast<const LabelSetImage *>(this->GetInput());
+    const auto *input = static_cast<const MultiLabelSegmentation *>(this->GetInput());
     if (input)
       return Supported;
     else
@@ -66,7 +66,7 @@ namespace mitk
   {
     ValidateOutputLocation();
 
-    auto input = dynamic_cast<const LabelSetImage *>(this->GetInput());
+    auto input = dynamic_cast<const MultiLabelSegmentation *>(this->GetInput());
 
     mitk::LocaleSwitch localeSwitch("C");
 
@@ -164,20 +164,30 @@ namespace mitk
     //generate multi label images
     auto output = ConvertImageToLabelSetImage(rawimage);
 
-    //get label set definitions
+    //get label groups definitions
     auto jsonStr = MultiLabelIOHelper::GetStringByKey(dictionary, MULTILABEL_SEGMENTATION_LABELS_INFO_KEY);
     nlohmann::json jlabelsets = nlohmann::json::parse(jsonStr);
-    auto labelsets = MultiLabelIOHelper::DeserializeMultiLabelGroupsFromJSON(jlabelsets);
+    auto labelGroups = MultiLabelIOHelper::DeserializeMultiLabelGroupsFromJSON(jlabelsets);
 
-    if (labelsets.size() != output->GetNumberOfLayers())
+    if (labelGroups.empty() && output->GetNumberOfGroups()==1)
     {
-      mitkThrow() << "Loaded data is in an invalid state. Number of extracted layer images and labels sets does not match. Found layer images: " << output->GetNumberOfLayers() << "; found labelsets: " << labelsets.size();
+      if (output->GetTotalNumberOfLabels() > 0)
+      {
+        mitkThrow() << "Loaded data is in an invalid state. Data contains no meta information for labels but pixel content indicates labels. Number of detected invalid labels: " << output->GetTotalNumberOfLabels();
+      }
+
+      MITK_INFO << "Segmentation contains only one layer and has no label information. Assuming empty label.";
+    }
+    else if (labelGroups.size() != output->GetNumberOfGroups())
+    {
+      mitkThrow() << "Loaded data is in an invalid state. Number of extracted layer images and labels sets does not match. Found layer images: " << output->GetNumberOfGroups() << "; found label groups: " << labelGroups.size();
     }
 
-    LabelSetImage::GroupIndexType id = 0;
-    for (auto labelset : labelsets)
+    MultiLabelSegmentation::GroupIndexType id = 0;
+    for (auto& groupInfo : labelGroups)
     {
-      output->ReplaceGroupLabels(id, labelset);
+      output->ReplaceGroupLabels(id, groupInfo.labels);
+      if (!groupInfo.name.empty()) output->SetGroupName(id, groupInfo.name);
       id++;
     }
 
@@ -188,7 +198,20 @@ namespace mitk
     auto props = ItkImageIO::ExtractMetaDataAsPropertyList(nrrdImageIO->GetMetaDataDictionary(), this->GetMimeType()->GetName(), this->m_DefaultMetaDataKeys);
     for (auto& [name, prop] : *(props->GetMap()))
     {
-      output->SetProperty(name, prop->Clone()); //need to clone to avoid that all outputs pointing to the same prop instances.
+      bool addProp = true;
+      for (auto unwantedName : m_DefaultMetaDataKeys)
+      {
+        // Only add properties that are not default meta information
+        if (name.substr(0, unwantedName.length()).find(unwantedName) != std::string::npos)
+        {
+          addProp = false;
+          break;
+        }
+      }
+      if (addProp)
+      {
+        output->SetProperty(name, prop->Clone()); //need to clone to avoid that all outputs pointing to the same prop instances.
+      }
     }
 
     // Handle UID
@@ -211,6 +234,7 @@ namespace mitk
 
   void MultiLabelSegmentationIO::InitializeDefaultMetaDataKeys()
   {
+    this->m_DefaultMetaDataKeys.push_back("org.mitk.uid");
     this->m_DefaultMetaDataKeys.push_back("NRRD.space");
     this->m_DefaultMetaDataKeys.push_back("NRRD.kinds");
     this->m_DefaultMetaDataKeys.push_back(PROPERTY_NAME_TIMEGEOMETRY_TYPE);
