@@ -11,64 +11,15 @@ found in the LICENSE file.
 ============================================================================*/
 
 #include "mitkMultilabelIOMimeTypes.h"
+
+#include <mitkFileSystem.h>
 #include <mitkIOMimeTypes.h>
 #include <mitkLog.h>
-#include <mitkFileSystem.h>
+
 #include <fstream>
 
-#include <nlohmann/json.hpp>
-
 #include <itkNrrdImageIO.h>
-#include "itkMetaDataObject.h"
-
-mitk::MitkMultilabelIOMimeTypes::MitkSegmentationTaskListMimeType::MitkSegmentationTaskListMimeType()
-  : CustomMimeType(SEGMENTATIONTASKLIST_MIMETYPE_NAME())
-{
-  this->AddExtension("json");
-  this->SetCategory("MITK Segmentation Task List");
-  this->SetComment("MITK Segmentation Task List");
-}
-
-bool mitk::MitkMultilabelIOMimeTypes::MitkSegmentationTaskListMimeType::AppliesTo(const std::string& path) const
-{
-  bool result = CustomMimeType::AppliesTo(path);
-
-  if (!fs::exists(path)) // T18572
-    return result;
-
-  std::ifstream file(path);
-
-  if (!file.is_open())
-    return false;
-
-  auto json = nlohmann::json::parse(file, nullptr, false);
-
-  if (json.is_discarded() || !json.is_object())
-    return false;
-
-  if ("MITK Segmentation Task List" != json.value("FileFormat", ""))
-    return false;
-
-  if (1 != json.value<int>("Version", 0))
-    return false;
-
-  return true;
-}
-
-mitk::MitkMultilabelIOMimeTypes::MitkSegmentationTaskListMimeType* mitk::MitkMultilabelIOMimeTypes::MitkSegmentationTaskListMimeType::Clone() const
-{
-  return new MitkSegmentationTaskListMimeType(*this);
-}
-
-mitk::MitkMultilabelIOMimeTypes::MitkSegmentationTaskListMimeType mitk::MitkMultilabelIOMimeTypes::SEGMENTATIONTASKLIST_MIMETYPE()
-{
-  return MitkSegmentationTaskListMimeType();
-}
-
-std::string mitk::MitkMultilabelIOMimeTypes::SEGMENTATIONTASKLIST_MIMETYPE_NAME()
-{
-  return IOMimeTypes::DEFAULT_BASE_NAME() + ".segmentationtasklist";
-}
+#include <itkMetaDataObject.h>
 
 mitk::MitkMultilabelIOMimeTypes::LegacyLabelSetMimeType::LegacyLabelSetMimeType()
   : CustomMimeType(LEGACYLABELSET_MIMETYPE_NAME())
@@ -107,7 +58,7 @@ bool mitk::MitkMultilabelIOMimeTypes::LegacyLabelSetMimeType::AppliesTo(const st
   }
   catch(const std::exception& e)
   {
-    MITK_DEBUG << "Error while try to anylize NRRD file for LegacyLabelSetMimeType. File: " << path <<"; Error: " << e.what();
+    MITK_DEBUG << "Error while try to analyze NRRD file for LegacyLabelSetMimeType. File: " << path <<"; Error: " << e.what();
   }
   catch(...)
   {
@@ -137,10 +88,147 @@ std::string mitk::MitkMultilabelIOMimeTypes::LEGACYLABELSET_MIMETYPE_NAME()
   return IOMimeTypes::DEFAULT_BASE_NAME() + ".legacylabelsetimage";
 }
 
+mitk::MitkMultilabelIOMimeTypes::MultiLabelSegmentationMimeType::MultiLabelSegmentationMimeType()
+  : CustomMimeType(MULTILABEL_SEGMENTATION_MIMETYPE_NAME())
+{
+  this->AddExtension("nrrd");
+  this->AddExtension("NRRD");
+  this->SetCategory("MITK MultiLabel");
+  this->SetComment("MITK Segmentation");
+}
+
+bool mitk::MitkMultilabelIOMimeTypes::MultiLabelSegmentationMimeType::AppliesTo(const std::string& path) const
+{
+  bool canRead = CustomMimeType::AppliesTo(path);
+
+  if (!fs::exists(path)) // T18572
+    return canRead;
+
+  if (!canRead)
+  {
+    return false;
+  }
+
+  std::string value("");
+  try
+  {
+    std::ifstream file(path);
+
+    if (!file.is_open())
+      return false;
+
+    itk::NrrdImageIO::Pointer io = itk::NrrdImageIO::New();
+    io->SetFileName(path);
+    io->ReadImageInformation();
+
+    itk::MetaDataDictionary imgMetaDataDictionary = io->GetMetaDataDictionary();
+    itk::ExposeMetaData<std::string>(imgMetaDataDictionary, "modality", value);
+  }
+  catch (const std::exception& e)
+  {
+    MITK_DEBUG << "Error while try to analyze NRRD file for LegacyLabelSetMimeType. File: " << path << "; Error: " << e.what();
+  }
+  catch (...)
+  {
+    MITK_DEBUG << "Unknown error while try to analyze NRRD file for LegacyLabelSetMimeType. File: " << path;
+  }
+
+  if (value.compare("org.mitk.multilabel.segmentation") != 0)
+  {
+    return false;
+  }
+
+  return true;
+}
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelSegmentationMimeType* mitk::MitkMultilabelIOMimeTypes::MultiLabelSegmentationMimeType::Clone() const
+{
+  return new MultiLabelSegmentationMimeType(*this);
+}
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelSegmentationMimeType mitk::MitkMultilabelIOMimeTypes::MULTILABEL_SEGMENTATION_MIMETYPE()
+{
+  return MultiLabelSegmentationMimeType();
+}
+
+std::string mitk::MitkMultilabelIOMimeTypes::MULTILABEL_SEGMENTATION_MIMETYPE_NAME()
+{
+  return IOMimeTypes::DEFAULT_BASE_NAME() + ".multilabel.segmentation";
+}
+
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelMetaMimeType::MultiLabelMetaMimeType()
+  : CustomMimeType(MULTILABELMETA_MIMETYPE_NAME())
+{
+  this->AddExtension("mitklabel.json");
+
+  this->SetCategory("MITK MultiLabel");
+  this->SetComment("MITK MultiLabel meta data");
+}
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelMetaMimeType* mitk::MitkMultilabelIOMimeTypes::MultiLabelMetaMimeType::Clone() const
+{
+  return new MultiLabelMetaMimeType(*this);
+}
+
+bool mitk::MitkMultilabelIOMimeTypes::MultiLabelMetaMimeType::AppliesTo(const std::string& path) const
+{
+  return CustomMimeType::AppliesTo(path);
+};
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelMetaMimeType mitk::MitkMultilabelIOMimeTypes::MULTILABELMETA_MIMETYPE()
+{
+  return MultiLabelMetaMimeType();
+}
+
+std::string mitk::MitkMultilabelIOMimeTypes::MULTILABELMETA_MIMETYPE_NAME()
+{
+  return IOMimeTypes::DEFAULT_BASE_NAME() + ".multilabel.meta";
+}
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelNiftiStackMimeType::MultiLabelNiftiStackMimeType()
+  : CustomMimeType(MULTILABEL_NIFTISTACK_MIMETYPE_NAME())
+{
+  this->AddExtension("mitklabel.json");
+  this->AddExtension("nii");
+  this->AddExtension("nii.gz");
+  this->AddExtension("NII");
+  this->AddExtension("NII.GZ");
+  this->SetCategory("MITK MultiLabel");
+  this->SetComment("MITK Segmentation NIFTI Stack");
+}
+
+bool mitk::MitkMultilabelIOMimeTypes::MultiLabelNiftiStackMimeType::AppliesTo(const std::string& path) const
+{
+  bool canRead = CustomMimeType::AppliesTo(path);
+
+  if (!fs::exists(path)) // T18572
+    return canRead;
+
+  return canRead;
+}
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelNiftiStackMimeType* mitk::MitkMultilabelIOMimeTypes::MultiLabelNiftiStackMimeType::Clone() const
+{
+  return new MultiLabelNiftiStackMimeType(*this);
+}
+
+mitk::MitkMultilabelIOMimeTypes::MultiLabelNiftiStackMimeType mitk::MitkMultilabelIOMimeTypes::MULTILABEL_NIFTISTACK_MIMETYPE()
+{
+  return MultiLabelNiftiStackMimeType();
+}
+
+std::string mitk::MitkMultilabelIOMimeTypes::MULTILABEL_NIFTISTACK_MIMETYPE_NAME()
+{
+  return IOMimeTypes::DEFAULT_BASE_NAME() + ".multilabel.segmentation.stack.nifti";
+}
+
 std::vector<mitk::CustomMimeType*> mitk::MitkMultilabelIOMimeTypes::Get()
 {
   std::vector<CustomMimeType*> mimeTypes;
-  mimeTypes.push_back(SEGMENTATIONTASKLIST_MIMETYPE().Clone());
   mimeTypes.push_back(LEGACYLABELSET_MIMETYPE().Clone());
+  mimeTypes.push_back(MULTILABEL_SEGMENTATION_MIMETYPE().Clone());
+  mimeTypes.push_back(MULTILABELMETA_MIMETYPE().Clone());
+  mimeTypes.push_back(MULTILABEL_NIFTISTACK_MIMETYPE().Clone());
   return mimeTypes;
 }
