@@ -17,10 +17,13 @@ found in the LICENSE file.
 
 #include "ChangeTextRegistry.h"
 
-#include "ui_MinimalViewControls.h"
-
 #include <QSignalMapper>
 
+namespace Ui
+{
+  class MinimalViewControls;
+}
+
 class MinimalView : public berry::QtViewPart
 {
   Q_OBJECT
@@ -40,7 +43,7 @@ private Q_SLOTS:
   void ChangeText(const QString &id);
 
 private:
-  Ui::MinimalViewControls m_Controls;
+  Ui::MinimalViewControls *m_Controls;
 
   QWidget *m_Parent;
   QSignalMapper m_SignalMapper;
