@@ -79,11 +79,11 @@ void QmitkPropertiesTableEditor::init()
 
   _PropertyFilterKeyWordPane->setLayout(_PropertyFilterKeyWordLayout);
 
-  _PropertyFilterKeyWordLayout->setMargin(0);
+  _PropertyFilterKeyWordLayout->setContentsMargins({});
   _PropertyFilterKeyWordLayout->addWidget(_LabelPropertyFilterKeyWord);
   _PropertyFilterKeyWordLayout->addWidget(m_TxtPropertyFilterKeyWord);
 
-  _NodePropertiesLayout->setMargin(0);
+  _NodePropertiesLayout->setContentsMargins({});
   _NodePropertiesLayout->addWidget(_PropertyFilterKeyWordPane);
   _NodePropertiesLayout->addWidget(m_NodePropertiesTableView);
 
