@@ -24,6 +24,7 @@ found in the LICENSE file.
 
 QmitkSynchronizedNodeSelectionWidget::QmitkSynchronizedNodeSelectionWidget(QWidget* parent)
   : QmitkAbstractNodeSelectionWidget(parent)
+  , m_SyncGroupIndex(-1)
 {
   m_Controls.setupUi(this);
 
@@ -35,21 +36,26 @@ QmitkSynchronizedNodeSelectionWidget::QmitkSynchronizedNodeSelectionWidget(QWidg
   m_Controls.tableView->setSelectionMode(QAbstractItemView::SingleSelection);
   m_Controls.tableView->setSelectionBehavior(QAbstractItemView::SelectRows);
   m_Controls.tableView->setContextMenuPolicy(Qt::CustomContextMenu);
-  m_Controls.tableView->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
   m_Controls.tableView->verticalHeader()->setSectionResizeMode(QHeaderView::ResizeToContents);
 
+  auto header = m_Controls.tableView->horizontalHeader();
+  header->setSectionResizeMode(0, QHeaderView::Stretch);
+
+  const int columnCount = m_StorageModel->columnCount();
+
+  for (int column = 1; column < columnCount; ++column)
+  {
+    header->setSectionResizeMode(column, QHeaderView::ResizeToContents);
+  }
+
   this->SetUpConnections();
   this->Initialize();
 }
 
 QmitkSynchronizedNodeSelectionWidget::~QmitkSynchronizedNodeSelectionWidget()
 {
-  bool isSynchronized = this->IsSynchronized();
-  if (isSynchronized)
-  {
-    emit DeregisterSynchronization();
-    return;
-  }
+
+  emit DeregisterSynchronization();
 
   auto baseRenderer = m_BaseRenderer.Lock();
   if (baseRenderer.IsNull())
@@ -63,8 +69,7 @@ QmitkSynchronizedNodeSelectionWidget::~QmitkSynchronizedNodeSelectionWidget()
     return;
   }
 
-  // If the model is not synchronized,
-  // we know that renderer-specific properties exist for all nodes.
+  // We know that renderer-specific properties exist for all nodes.
   // These properties need to be removed from the nodes.
   auto allNodes = dataStorage->GetAll();
   for (auto& node : *allNodes)
@@ -89,6 +94,7 @@ void QmitkSynchronizedNodeSelectionWidget::SetBaseRenderer(mitk::BaseRenderer* b
 
   auto oldBaseRenderer = m_BaseRenderer.Lock();
   m_BaseRenderer = baseRenderer;
+  m_StorageModel->SetCurrentRenderer(baseRenderer);
 
   auto dataStorage = m_DataStorage.Lock();
   if (dataStorage.IsNull())
@@ -96,35 +102,28 @@ void QmitkSynchronizedNodeSelectionWidget::SetBaseRenderer(mitk::BaseRenderer* b
     return;
   }
 
-  bool isSynchronized = this->IsSynchronized();
-  if (isSynchronized)
+  // We know that renderer-specific properties exist for all nodes.
+  // These properties need to be removed from the nodes and
+  // we need to transfer their values to new renderer-specific properties.
+  auto allNodes = dataStorage->GetAll();
+  for (auto& node : *allNodes)
   {
-    // If the model is synchronized,
-    // all nodes use global / default properties.
-    // No renderer-specific property lists should exist
-    // so there is no need to transfer any property values.
-  }
-  else
-  {
-    // If the model is not synchronized,
-    // we know that renderer-specific properties exist for all nodes.
-    // These properties need to be removed from the nodes and
-    // we need to transfer their values to new renderer-specific properties.
-    auto allNodes = dataStorage->GetAll();
-    for (auto& node : *allNodes)
-    {
-      // Set the relevant renderer-specific properties for the node using the new base renderer.
-      // By transferring the values from the old property list,
-      // the same property-state is kept when switching to another base renderer.
-      mitk::RenderWindowLayerUtilities::TransferRenderWindowProperties(node, baseRenderer, oldBaseRenderer);
-      // Delete the relevant renderer-specific properties for the node using the old base renderer.
-      mitk::RenderWindowLayerUtilities::DeleteRenderWindowProperties(node, oldBaseRenderer);
-    }
+    // Set the relevant renderer-specific properties for the node using the new base renderer.
+    // By transferring the values from the old property list,
+    // the same property-state is kept when switching to another base renderer.
+    mitk::RenderWindowLayerUtilities::TransferRenderWindowProperties(node, baseRenderer, oldBaseRenderer);
+    // Delete the relevant renderer-specific properties for the node using the old base renderer.
+    mitk::RenderWindowLayerUtilities::DeleteRenderWindowProperties(node, oldBaseRenderer);
   }
 
   this->Initialize();
 }
 
+QmitkRenderWindowDataNodeTableModel* QmitkSynchronizedNodeSelectionWidget::GetStorageModel() const
+{
+  return m_StorageModel.get();
+}
+
 void QmitkSynchronizedNodeSelectionWidget::SetSelectAll(bool selectAll)
 {
   if (selectAll == m_Controls.selectionModeCheckBox->isChecked())
@@ -141,102 +140,6 @@ bool QmitkSynchronizedNodeSelectionWidget::GetSelectAll() const
   return m_Controls.selectionModeCheckBox->isChecked();
 }
 
-void QmitkSynchronizedNodeSelectionWidget::SetSynchronized(bool synchronize)
-{
-  if (synchronize == this->IsSynchronized())
-  {
-    // no need to do something
-    return;
-  }
-
-  auto baseRenderer = m_BaseRenderer.Lock();
-  if (baseRenderer.IsNull())
-  {
-    return;
-  }
-
-  auto dataStorage = m_DataStorage.Lock();
-  if (dataStorage.IsNull())
-  {
-    return;
-  }
-
-  if (synchronize)
-  {
-    // set the base renderer of the model to nullptr, such that global properties are used
-    m_StorageModel->SetCurrentRenderer(nullptr);
-
-    // If the model is synchronized,
-    // we know that the model was not synchronized before.
-    // That means that all nodes use renderer-specific properties,
-    // but now all nodes need global properties.
-    // Thus we need to remove the renderer-specific properties of all nodes of the
-    // datastorage.
-    auto allNodes = dataStorage->GetAll();
-    for (auto& node : *allNodes)
-    {
-      // For helper / hidden nodes:
-      // If the node predicate does not match, do not remove the renderer-specific property
-      // This is relevant for the crosshair data nodes, which are only visible inside their
-      // corresponding render window.
-      if (m_NodePredicate.IsNull() || m_NodePredicate->CheckNode(node))
-      {
-        // Delete the relevant renderer-specific properties for the node using the current base renderer.
-        mitk::RenderWindowLayerUtilities::DeleteRenderWindowProperties(node, baseRenderer);
-      }
-    }
-  }
-  else
-  {
-    // set the base renderer of the model to current base renderer, such that renderer-specific properties are used
-    m_StorageModel->SetCurrentRenderer(baseRenderer);
-
-    // If the model is not synchronized anymore,
-    // we know that the model was synchronized before.
-    // That means that all nodes use global / default properties,
-    // but now all nodes need renderer-specific properties.
-    // Thus we need to modify the renderer-specific properties of all nodes of the
-    // datastorage:
-    //  - hide those nodes, which are not part of the newly selected nodes.
-    //  - keep the property values of those nodes, which are part of the new selection AND
-    //    have been selected before
-    auto currentNodeSelection = this->GetCurrentInternalSelection();
-    auto allNodes = dataStorage->GetAll();
-    for (auto& node : *allNodes)
-    {
-      // check if the node is part of the current selection
-      auto finding = std::find(std::begin(currentNodeSelection), std::end(currentNodeSelection), node);
-      if (finding != std::end(currentNodeSelection)) // node found / part of the current selection
-      {
-        // Set the relevant renderer-specific properties for the node using the current base renderer.
-        // By transferring the values from the global / default property list,
-        // the same property-state is kept when switching to non-synchronized mode.
-        mitk::RenderWindowLayerUtilities::TransferRenderWindowProperties(node, baseRenderer, nullptr);
-      }
-      else
-      {
-        // If the node is not part of the selection, unset the relevant renderer-specific properties.
-        // This will unset the "visible" and "layer" property for the renderer-specific property list and
-        // hide the node for this renderer.
-        // ATTENTION: This is required, since the synchronized property needs to be overwritten
-        //            to make sure that the visibility is correctly set for the specific base renderer.
-        this->DeselectNode(node);
-      }
-    }
-  }
-
-  // Since the synchronization might lead to a different node order depending on the layer properties, the render window
-  // needs to be updated.
-  // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
-  // see https://phabricator.mitk.org/T22322
-  mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
-}
-
-bool QmitkSynchronizedNodeSelectionWidget::IsSynchronized() const
-{
-  return m_StorageModel->GetCurrentRenderer().IsNull();
-}
-
 void QmitkSynchronizedNodeSelectionWidget::OnSelectionModeChanged(bool selectAll)
 {
   emit SelectionModeChanged(selectAll);
@@ -259,8 +162,11 @@ void QmitkSynchronizedNodeSelectionWidget::OnEditSelection()
   m_Controls.changeSelectionButton->setChecked(true);
   if (dialog->exec())
   {
-    m_Controls.selectionModeCheckBox->setChecked(false);
-    emit SelectionModeChanged(false);
+    if (m_Controls.selectionModeCheckBox->isChecked())
+    {
+      m_Controls.selectionModeCheckBox->setChecked(false);
+      emit SelectionModeChanged(false);
+    }
 
     auto selectedNodes = dialog->GetSelectedNodes();
     this->HandleChangeOfInternalSelection(selectedNodes);
@@ -289,8 +195,9 @@ void QmitkSynchronizedNodeSelectionWidget::OnTableClicked(const QModelIndex& ind
 
   if (index.column() == 1) // node visibility column
   {
-    bool visibiliy = index.data(Qt::EditRole).toBool();
-    m_StorageModel->setData(index, QVariant(!visibiliy), Qt::EditRole);
+    bool visibility = index.data(Qt::EditRole).toBool();
+    m_StorageModel->setData(index, QVariant(!visibility), Qt::EditRole);
+    emit NodeVisibilityChanged(dataNode, !visibility);
     return;
   }
 
@@ -349,9 +256,6 @@ void QmitkSynchronizedNodeSelectionWidget::Initialize()
   m_Controls.changeSelectionButton->setEnabled(true);
 
   m_Controls.selectionModeCheckBox->setChecked(true);
-
-  // set the base renderer of the model to nullptr, such that global properties are used (synchronized mode)
-  m_StorageModel->SetCurrentRenderer(nullptr);
 }
 
 void QmitkSynchronizedNodeSelectionWidget::UpdateInfo()
@@ -377,179 +281,7 @@ void QmitkSynchronizedNodeSelectionWidget::ReviseSelectionChanged(const NodeList
     return;
   }
 
-  bool isSynchronized = this->IsSynchronized();
-  if (isSynchronized)
-  {
-    this->ReviseSynchronizedSelectionChanged(oldInternalSelection, newInternalSelection);
-  }
-  else
-  {
-    this->ReviseDesynchronizedSelectionChanged(oldInternalSelection, newInternalSelection);
-  }
-
-  // Since a new selection might have a different rendering tree the render windows
-  // need to be updated.
-  // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
-  // see https://phabricator.mitk.org/T22322
-  mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
-}
-
-void QmitkSynchronizedNodeSelectionWidget::OnInternalSelectionChanged()
-{
-  m_StorageModel->SetCurrentSelection(this->GetCurrentInternalSelection());
-}
-
-bool QmitkSynchronizedNodeSelectionWidget::AllowEmissionOfSelection(const NodeList& /*emissionCandidates*/) const
-{
-  return this->IsSynchronized();
-}
-
-void QmitkSynchronizedNodeSelectionWidget::OnNodeAddedToStorage(const mitk::DataNode* node)
-{
-  auto baseRenderer = m_BaseRenderer.Lock();
-  if (baseRenderer.IsNull())
-  {
-    return;
-  }
-
-  // For helper / hidden nodes
-  if (m_NodePredicate.IsNotNull() && !m_NodePredicate->CheckNode(node))
-  {
-    // If the node predicate does not match, do not add the node to the current selection.
-    // Leave the visibility as it is.
-    return;
-  }
-
-  // The selection mode determines if we want to show all nodes from the data storage
-  // or use a local selected list of nodes.
-  // We need to hide each new incoming data node, if we use a local selection,
-  // since we do not want to show / select newly added nodes immediately.
-  // We need to add the incoming node to our selection, if the selection mode check box
-  // is checked.
-  // We want to add the incoming node to our selection, if the node is a child node
-  // of an already selected node.
-  // Nodes added to the selection will be made visible.
-  if (m_Controls.selectionModeCheckBox->isChecked() || this->IsParentNodeSelected(node))
-  {
-    auto currentSelection = this->GetCurrentInternalSelection();
-    // Check if the nodes is already part of the internal selection.
-    // That can happen if another render window already added the new node and sent out the new, updated
-    // selection to be synchronized.
-    auto finding = std::find(std::begin(currentSelection), std::end(currentSelection), node);
-    if (finding != std::end(currentSelection)) // node found
-    {
-      // node already part of the selection
-      return;
-    }
-
-    currentSelection.append(const_cast<mitk::DataNode*>(node));
-    // This function will call 'QmitkSynchronizedNodeSelectionWidget::ReviseSelectionChanged'
-    // which will take care of the visibility-property for newly added node.
-    this->HandleChangeOfInternalSelection(currentSelection);
-  }
-  else
-  {
-    // If the widget is in "local-selection" state (selectionModeCheckBox unchecked),
-    // the new incoming node needs to be hid.
-    // Here it depends on the synchronization-state which properties need
-    // to be modified.
-    if (this->IsSynchronized())
-    {
-      // If the node will not be part of the new selection, hide the node.
-      const_cast<mitk::DataNode*>(node)->SetVisibility(false);
-    }
-    else
-    {
-      // If the widget is not synchronized, all nodes use renderer-specific properties.
-      // Thus we need to modify the renderer-specific properties of the node:
-      //  - hide the node, which is not part of the selection
-      this->DeselectNode(const_cast<mitk::DataNode*>(node));
-    }
-  }
-}
-
-void QmitkSynchronizedNodeSelectionWidget::OnNodeModified(const itk::Object* caller, const itk::EventObject& event)
-{
-  auto baseRenderer = m_BaseRenderer.Lock();
-  if (baseRenderer.IsNull())
-  {
-    return;
-  }
-
-  if (!itk::ModifiedEvent().CheckEvent(&event))
-  {
-    return;
-  }
-
-  auto node = dynamic_cast<const mitk::DataNode*>(caller);
-
-  if (m_NodePredicate.IsNull() || m_NodePredicate->CheckNode(node))
-  {
-    auto currentSelection = this->GetCurrentInternalSelection();
-    // check if the node to be modified is part of the current selection
-    auto finding = std::find(std::begin(currentSelection), std::end(currentSelection), node);
-    if (finding == std::end(currentSelection)) // node not found
-    {
-      // node not part of the selection
-      return;
-    }
-    
-    // We know that the node is relevant, but we don't know if the node modification was relevant
-    // for the rendering. We just request an update here.
-    // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
-    // see https://phabricator.mitk.org/T22322
-    mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
-    m_StorageModel->UpdateModelData();
-  }
-}
-
-void QmitkSynchronizedNodeSelectionWidget::ReviseSynchronizedSelectionChanged(const NodeList& oldInternalSelection, NodeList& newInternalSelection)
-{
-  // If the model is synchronized, all nodes use global / default properties.
-  // Thus we need to modify the global properties of the selection:
-  //  - a) show those nodes, which are part of the new selection AND have not been
-  //       selected before
-  //  - b) keep the property values of those nodes, which are part of the new selection AND
-  //       have been selected before
-  //  - c) hide those nodes, which are part of the old selection AND
-  //       have not been newly selected
-  for (auto& node : newInternalSelection)
-  {
-    // check if the node is part of the old selection
-    auto finding = std::find(std::begin(oldInternalSelection), std::end(oldInternalSelection), node);
-    if (finding == std::end(oldInternalSelection)) // node not found
-    {
-      // If the node is part of the new selection and was not already part of the old selection,
-      // set the relevant renderer-specific properties.
-      // This will set the "visible" property for the global / default property list
-      // and show the node for this renderer.
-      node->SetVisibility(true); // item a)
-    }
-    // else: item b): node that was already selected before does not need to be modified
-  }
-
-  for (auto& node : oldInternalSelection)
-  {
-    // check if the node is part of the new selection
-    auto finding = std::find(std::begin(newInternalSelection), std::end(newInternalSelection), node);
-    if (finding == std::end(newInternalSelection)) // node not found
-    {
-      // If the node is not part of the new selection, hide the node.
-      node->SetVisibility(false); // item c)
-    }
-    // else: item b): node that was already selected before does not need to be modified
-  }
-}
-
-void QmitkSynchronizedNodeSelectionWidget::ReviseDesynchronizedSelectionChanged(const NodeList& oldInternalSelection, NodeList& newInternalSelection)
-{
-  auto baseRenderer = m_BaseRenderer.Lock();
-  if (baseRenderer.IsNull())
-  {
-    return;
-  }
-
-  // If the model is not synchronized, all nodes need renderer-specific properties.
+  // Since the model is synchronized to a group, all nodes need renderer-specific properties.
   // Thus we need to modify the renderer-specific properties of the selection:
   //  - a) set the renderer-specific properties of those nodes, which are part of the new selection AND
   //       have not been selected before (see 'SelectNode')
@@ -593,6 +325,106 @@ void QmitkSynchronizedNodeSelectionWidget::ReviseDesynchronizedSelectionChanged(
     }
     // else: item c): node that was already selected before does not need to be modified
   }
+
+  // Since a new selection might have a different rendering tree the render windows
+  // need to be updated.
+  // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
+  // see https://phabricator.mitk.org/T22322
+  mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
+}
+
+void QmitkSynchronizedNodeSelectionWidget::OnInternalSelectionChanged()
+{
+  m_StorageModel->SetCurrentSelection(this->GetCurrentInternalSelection());
+}
+
+void QmitkSynchronizedNodeSelectionWidget::OnNodeAddedToStorage(const mitk::DataNode* node)
+{
+  auto baseRenderer = m_BaseRenderer.Lock();
+  if (baseRenderer.IsNull())
+  {
+    return;
+  }
+
+  // For helper / hidden nodes
+  if (m_NodePredicate.IsNotNull() && !m_NodePredicate->CheckNode(node))
+  {
+    // If the node predicate does not match, do not add the node to the current selection.
+    // Leave the visibility as it is.
+    return;
+  }
+
+
+  bool visibleInRenderer = false;
+  if (node->PropertyIsOwned("visible", baseRenderer->GetName(), false))
+    node->GetBoolProperty("visible", visibleInRenderer, baseRenderer);
+  // The selection mode determines if we want to show all nodes from the data storage
+  // or use a local selected list of nodes.
+  // We need to hide each new incoming data node, if we use a local selection,
+  // since we do not want to show / select newly added nodes immediately.
+  // We need to add the incoming node to our selection, if the selection mode check box
+  // is checked.
+  // We want to add the incoming node to our selection, if the node is a child node
+  // of an already selected node or it is already explicitly visible for this renderer
+  // via properties.
+  // Nodes added to the selection will be made visible.
+  if (m_Controls.selectionModeCheckBox->isChecked() || this->IsParentNodeSelected(node) || visibleInRenderer)
+  {
+    auto currentSelection = this->GetCurrentInternalSelection();
+    // Check if the nodes is already part of the internal selection.
+    // That can happen if another render window already added the new node and sent out the new, updated
+    // selection to be synchronized.
+    auto finding = std::find(std::begin(currentSelection), std::end(currentSelection), node);
+    if (finding != std::end(currentSelection)) // node found
+    {
+      // node already part of the selection
+      return;
+    }
+
+    currentSelection.append(const_cast<mitk::DataNode*>(node));
+    // This function will call 'QmitkSynchronizedNodeSelectionWidget::ReviseSelectionChanged'
+    // which will take care of the visibility-property for newly added node.
+    this->HandleChangeOfInternalSelection(currentSelection);
+  }
+  else
+  {
+    this->DeselectNode(const_cast<mitk::DataNode*>(node));
+  }
+}
+
+void QmitkSynchronizedNodeSelectionWidget::OnNodeModified(const itk::Object* caller, const itk::EventObject& event)
+{
+  auto baseRenderer = m_BaseRenderer.Lock();
+  if (baseRenderer.IsNull())
+  {
+    return;
+  }
+
+  if (!itk::ModifiedEvent().CheckEvent(&event))
+  {
+    return;
+  }
+
+  auto node = dynamic_cast<const mitk::DataNode*>(caller);
+
+  if (m_NodePredicate.IsNull() || m_NodePredicate->CheckNode(node))
+  {
+    auto currentSelection = this->GetCurrentInternalSelection();
+    // check if the node to be modified is part of the current selection
+    auto finding = std::find(std::begin(currentSelection), std::end(currentSelection), node);
+    if (finding == std::end(currentSelection)) // node not found
+    {
+      // node not part of the selection
+      return;
+    }
+    
+    // We know that the node is relevant, but we don't know if the node modification was relevant
+    // for the rendering. We just request an update here.
+    // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
+    // see https://phabricator.mitk.org/T22322
+    mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
+    m_StorageModel->UpdateModelData();
+  }
 }
 
 void QmitkSynchronizedNodeSelectionWidget::ReinitNode(const mitk::DataNode* dataNode)
@@ -627,18 +459,13 @@ void QmitkSynchronizedNodeSelectionWidget::RemoveFromInternalSelection(mitk::Dat
     return;
   }
 
-  if (this->IsSynchronized())
+  if (m_Controls.selectionModeCheckBox->isChecked())
   {
-    // If the model is synchronized, all nodes use global / default properties.
-    // Thus we need to modify the global property of the node.
-    // Explicitly set the visibility to false for unselected nodes to hide them in the render window.
-    dataNode->SetVisibility(false);
+    m_Controls.selectionModeCheckBox->setChecked(false);
+    emit SelectionModeChanged(false);
   }
 
-  m_Controls.selectionModeCheckBox->setChecked(false);
-  emit SelectionModeChanged(false);
-
-  this->RemoveNodeFromSelection(dataNode);
+  this->RemoveNodeFromInternalSelection(dataNode);
 }
 
 bool QmitkSynchronizedNodeSelectionWidget::IsParentNodeSelected(const mitk::DataNode* dataNode) const
@@ -706,3 +533,45 @@ void QmitkSynchronizedNodeSelectionWidget::SelectAll()
 
   this->HandleChangeOfInternalSelection(currentSelection);
 }
+
+void QmitkSynchronizedNodeSelectionWidget::SetSyncGroup(const GroupSyncIndexType index)
+{
+  auto baseRenderer = m_BaseRenderer.Lock();
+  if (baseRenderer.IsNull())
+  {
+    return;
+  }
+
+  if (index == 0)
+  {
+    MITK_ERROR << "Invalid call to SetSyncGroup. Group index can't be 0.";
+    return;
+  }
+
+  m_SyncGroupIndex = index;
+
+  // Since the synchronization might lead to a different node order depending on the layer properties, the render window
+  // needs to be updated.
+  // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
+  // see https://phabricator.mitk.org/T22322
+  mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
+}
+
+QmitkSynchronizedNodeSelectionWidget::GroupSyncIndexType QmitkSynchronizedNodeSelectionWidget::GetSyncGroup() const
+{
+  return m_SyncGroupIndex;
+}
+
+void QmitkSynchronizedNodeSelectionWidget::SetNodeVisibility(mitk::DataNode::Pointer node, const bool visibility)
+{
+  auto baseRenderer = m_BaseRenderer.Lock();
+  if (baseRenderer.IsNull())
+  {
+    return;
+  }
+  node->SetVisibility(visibility, baseRenderer);
+
+  // Explicitly request an update since a renderer-specific property change does not mark the node as modified.
+  // see https://phabricator.mitk.org/T22322
+  mitk::RenderingManager::GetInstance()->RequestUpdate(baseRenderer->GetRenderWindow());
+}
