@@ -33,7 +33,7 @@ public:
   ///
   /// standard ctor, init values to defaults (see methods for values)
   ///
-  explicit QmitkFileChooser(QWidget *parent = nullptr, Qt::WindowFlags f = nullptr);
+  explicit QmitkFileChooser(QWidget *parent = nullptr, Qt::WindowFlags f = {});
 
   ///
   /// determines whether the button "Select file" is shown on the left
@@ -73,7 +73,7 @@ public:
 
 signals:
   ///
-  /// emitted when the input changed programatically or by the user
+  /// emitted when the input changed programmatically or by the user
   ///
   void NewFileSelected(const std::string &);
 
