@@ -13,7 +13,6 @@ found in the LICENSE file.
 
 #include <QApplication>
 #include <QCloseEvent>
-#include <QDesktopWidget>
 #include <QLayout>
 #include <QMouseEvent>
 #include <QPainter>
@@ -121,7 +120,7 @@ void QmitkPopupColorChooser::closeEvent(QCloseEvent *e)
   if (!m_popupParent)
     return;
 
-  // remember that we (as a popup) might recieve the mouse release
+  // remember that we (as a popup) might receive the mouse release
   // event instead of the popupParent. This is due to the fact that
   // the popupParent popped us up in its mousePressEvent handler. To
   // avoid the button remaining in pressed state we simply send a
@@ -227,16 +226,9 @@ int QmitkColorPropertyEditor::colorChooserRefCount = 0;
 QmitkColorPropertyEditor::QmitkColorPropertyEditor(const mitk::ColorProperty *property, QWidget *parent)
   : QmitkColorPropertyView(property, parent)
 {
-  // our popup belongs to the whole screen, so it could be drawn outside the toplevel window's borders
-  int scr;
-  if (QApplication::desktop()->isVirtualDesktop())
-    scr = QApplication::desktop()->screenNumber(parent->mapToGlobal(pos()));
-  else
-    scr = QApplication::desktop()->screenNumber(parent);
-
   if (colorChooserRefCount == 0)
   {
-    colorChooser = new QmitkPopupColorChooser(QApplication::desktop()->screen(scr), 50);
+    colorChooser = new QmitkPopupColorChooser(nullptr, 50);
   }
   ++colorChooserRefCount;
 }
