@@ -80,7 +80,7 @@ void mitk::CorrectorAlgorithm::GenerateData()
 
   Image::Pointer temporarySlice;
 
-  // Convert to DefaultSegmentationDataType (because TobiasHeimannCorrectionAlgorithm relys on that data type)
+  // Convert to DefaultSegmentationDataType (because TobiasHeimannCorrectionAlgorithm relies on that data type)
   {
     itk::Image<DefaultSegmentationDataType, 2>::Pointer correctPixelTypeImage;
     CastToItkImage(m_WorkingImage, correctPixelTypeImage);
@@ -176,7 +176,6 @@ bool mitk::CorrectorAlgorithm::ImprovedHeimannCorrectionAlgorithm(
 
   int currentColor = (pic->GetPixel(previousIndex) == m_FillColor);
   TSegData currentSegment;
-  int countOfSegments = 1;
 
   bool firstSegment = true;
   auto contourEnd = projectedContour->End();
@@ -212,7 +211,6 @@ bool mitk::CorrectorAlgorithm::ImprovedHeimannCorrectionAlgorithm(
           firstSegment = false;
         }
         currentSegment = TSegData();
-        ++countOfSegments;
         currentColor = (pic->GetPixel(temporaryIndex) == m_FillColor);
       }
       currentSegment.points.push_back(temporaryIndex);
