@@ -1,47 +1,38 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include <usGetModuleContext.h>
+#include <usModule.h>
 #include <usModuleActivator.h>
 #include <usModuleContext.h>
-#include <usModule.h>
 
 #include "mitkToolManagerProvider.h"
 
 namespace mitk
 {
-
   /**
   \brief Registers services for segmentation module.
   */
   class SegmentationModuleActivator : public us::ModuleActivator
   {
   public:
-
-    void Load(us::ModuleContext* context) override
+    void Load(us::ModuleContext *context) override
     {
       /*register ToolManager provider service*/
       m_ToolManagerProvider = mitk::ToolManagerProvider::New();
       context->RegisterService<mitk::ToolManagerProvider>(m_ToolManagerProvider);
     }
 
-    void Unload(us::ModuleContext*) override
-    {
-    }
-
+    void Unload(us::ModuleContext *) override {}
   private:
     mitk::ToolManagerProvider::Pointer m_ToolManagerProvider;
   };
