@@ -42,7 +42,7 @@ namespace mitk
     us::ModuleResource GetIconResource() const override;
     void Activated() override;
     void WriteImage(const Image *inputAtTimeStep, const std::string &inputImagePath) const override;
-    void WriteBackResults(LabelSetImage *previewImage, LabelSetImage *segResults, TimeStepType timeStep) const override;
+    void WriteBackResults(MultiLabelSegmentation *previewImage, MultiLabelSegmentation *segResults, TimeStepType timeStep) const override;
 
   protected:
     MonaiLabel3DTool() = default;
