@@ -41,6 +41,9 @@ void mitk::MonaiLabelTool::ConnectActionsAndFunctions()
   CONNECT_FUNCTION("ShiftSecondaryButtonPressed", OnAddNegativePoint);
   CONNECT_FUNCTION("ShiftPrimaryButtonPressed", OnAddPositivePoint);
   CONNECT_FUNCTION("DeletePoint", OnDelete);
+  CONNECT_FUNCTION("Move", OnMove);
+  CONNECT_FUNCTION("Release", OnRelease);
+  CONNECT_FUNCTION("PrimaryButtonPressed", OnPrimaryButtonPressed);
 }
 
 void mitk::MonaiLabelTool::Activated()
@@ -92,32 +95,34 @@ void mitk::MonaiLabelTool::UpdatePrepare()
 
 void mitk::MonaiLabelTool::OnAddPositivePoint(StateMachineAction *, InteractionEvent *interactionEvent)
 {
-  if (m_RequestParameters->model.IsInteractive())
+  if (nullptr == m_RequestParameters || !m_RequestParameters->model.IsInteractive())
   {
-    if (m_RequestParameters->model.Is2D() && ((nullptr == this->GetWorkingPlaneGeometry()) ||
-        !mitk::Equal(*(interactionEvent->GetSender()->GetCurrentWorldPlaneGeometry()),
-                     *(this->GetWorkingPlaneGeometry()))))
+    return;
+  }
+
+  if (m_RequestParameters->model.Is2D() && ((nullptr == this->GetWorkingPlaneGeometry()) ||
+      !mitk::Equal(*(interactionEvent->GetSender()->GetCurrentWorldPlaneGeometry()),
+                    *(this->GetWorkingPlaneGeometry()))))
+  {
+    this->ClearSeeds();
+    this->SetWorkingPlaneGeometry(interactionEvent->GetSender()->GetCurrentWorldPlaneGeometry()->Clone());
+    this->ResetPreviewContent();
+  }
+  if (!this->IsUpdating() && m_PointSetPositive.IsNotNull())
+  {
+    const auto positionEvent = dynamic_cast<mitk::InteractionPositionEvent *>(interactionEvent);
+    if (positionEvent != nullptr)
     {
-      this->ClearSeeds();
-      this->SetWorkingPlaneGeometry(interactionEvent->GetSender()->GetCurrentWorldPlaneGeometry()->Clone());
-      this->ResetPreviewContent();
-    }
-    if (!this->IsUpdating() && m_PointSetPositive.IsNotNull())
-    {
-      const auto positionEvent = dynamic_cast<mitk::InteractionPositionEvent *>(interactionEvent);
-      if (positionEvent != nullptr)
-      {
-        m_PointSetPositive->InsertPoint(m_PointSetCount, positionEvent->GetPositionInWorld());
-        ++m_PointSetCount;
-        this->UpdatePreview();
-      }
+      m_PointSetPositive->InsertPoint(m_PointSetCount, positionEvent->GetPositionInWorld());
+      ++m_PointSetCount;
+      this->UpdatePreview();
     }
   }
 }
 
 void mitk::MonaiLabelTool::OnAddNegativePoint(StateMachineAction *, InteractionEvent *interactionEvent)
 {
-  if ("deepgrow" != m_RequestParameters->model.type)
+  if (nullptr == m_RequestParameters || "deepgrow" != m_RequestParameters->model.type)
   {
     return;
   }
@@ -285,10 +290,10 @@ namespace
   }
 
   /**
-   * @brief Applies the give std::map lookup table on the preview segmentation LabelSetImage.
+   * @brief Applies the give std::map lookup table on the preview segmentation MultiLabelSegmentation.
    */
-  void MapLabelsToSegmentation(const mitk::LabelSetImage *source,
-                               mitk::LabelSetImage *dest,
+  void MapLabelsToSegmentation(const mitk::MultiLabelSegmentation *source,
+                               mitk::MultiLabelSegmentation *dest,
                                const std::map<std::string, mitk::Label::PixelType> &labelMap)
   {
     if (labelMap.empty())
@@ -360,7 +365,7 @@ mitk::Image::Pointer mitk::MonaiLabelTool::ApplyLevelWindowEffect(const Image *i
 
 void mitk::MonaiLabelTool::DoUpdatePreview(const Image *inputAtTimeStep,
                                            const Image * /*oldSegAtTimeStep*/,
-                                           LabelSetImage *previewImage,
+                                           MultiLabelSegmentation *previewImage,
                                            TimeStepType timeStep)
 {
   if (nullptr == m_RequestParameters || (m_RequestParameters->model.IsInteractive() && !this->HasPicks()))
@@ -389,7 +394,7 @@ void mitk::MonaiLabelTool::DoUpdatePreview(const Image *inputAtTimeStep,
     this->WriteImage(filteredImage, inputImagePath);
     this->PostInferRequest(hostName, port, inputImagePath, outputImagePath, inputAtTimeStep->GetGeometry());
     auto outputImage = IOUtil::Load<Image>(outputImagePath);
-    auto outputBuffer = mitk::LabelSetImage::New();
+    auto outputBuffer = mitk::MultiLabelSegmentation::New();
     outputBuffer->InitializeByLabeledImage(outputImage);
     std::map<std::string, mitk::Label::PixelType> labelMap; // empty map
     if (m_RequestParameters->model.IsInteractive())
@@ -446,7 +451,7 @@ void mitk::MonaiLabelTool::FetchOverallInfo(const std::string &hostName, const i
   }
   else
   {
-    Tool::ErrorMessage.Send(httplib::to_string(response.error()) + " error occured.");
+    Tool::ErrorMessage.Send(httplib::to_string(response.error()) + " error occurred.");
   }
 }
 
@@ -472,10 +477,12 @@ void mitk::MonaiLabelTool::PostInferRequest(const std::string &hostName,
   {
     std::string foreground = this->ConvertPointsAsListString(baseGeometry, m_PointSetPositive);
     std::string background = this->ConvertPointsAsListString(baseGeometry, m_PointSetNegative);
+    bool resetState = (m_PointSetPositive->GetSize() == 1 && m_PointSetNegative->GetSize() == 0);
     std::stringstream paramString;
     paramString << "{" 
                 << "\"foreground\":" << foreground 
                 << ",\"background\":" << background
+                << ",\"reset_state\":" << (resetState ? "true" : "false")
                 << "}";
     MITK_DEBUG << paramString.str();
     items.push_back({"params", paramString.str(), "", ""});
@@ -486,7 +493,7 @@ void mitk::MonaiLabelTool::PostInferRequest(const std::string &hostName,
   }
   items.push_back({"file", buffer_lf_img.str(), "post_from_mitk.nii.gz", "application/octet-stream"});
   httplib::SSLClient cli(hostName, port);
-  cli.set_read_timeout(60);                      // arbitary 1 minute time-out to avoid corner cases.
+  cli.set_read_timeout(m_Timeout);
   cli.enable_server_certificate_verification(false);
   if (auto response = cli.Post(postPath, items))
   {
@@ -526,8 +533,8 @@ void mitk::MonaiLabelTool::PostInferRequest(const std::string &hostName,
     else
     {
       auto err = response.error();
-      MITK_ERROR << "An HTTP POST error: " << httplib::to_string(err) << " occured.";
-      mitkThrow() << "An HTTP POST error: " << httplib::to_string(err) << " occured.";
+      MITK_ERROR << "An HTTP POST error: " << httplib::to_string(err) << " occurred.";
+      mitkThrow() << "An HTTP POST error: " << httplib::to_string(err) << " occurred.";
     }
   }
 }
@@ -658,3 +665,7 @@ const mitk::MonaiAppMetadata *mitk::MonaiLabelTool::GetInfoParameters() const
 {
   return m_InfoParameters.get();
 }
+
+void mitk::MonaiLabelTool::OnMove(mitk::StateMachineAction *, mitk::InteractionEvent *){};
+void mitk::MonaiLabelTool::OnRelease(mitk::StateMachineAction *, mitk::InteractionEvent *){};
+void mitk::MonaiLabelTool::OnPrimaryButtonPressed(mitk::StateMachineAction *, mitk::InteractionEvent *){};
