@@ -1,9 +1,20 @@
+/*============================================================================
+
+The Medical Imaging Interaction Toolkit (MITK)
+
+Copyright (c) German Cancer Research Center (DKFZ)
+All rights reserved.
+
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
+
+============================================================================*/
+
 #include "QmitkConfirmSegmentationDialog.h"
 #include "ui_QmitkConfirmSegmentationDialog.h"
 
-QmitkConfirmSegmentationDialog::QmitkConfirmSegmentationDialog(QWidget *parent) :
-  QDialog(parent),
-  m_Controls(new Ui::QmitkConfirmSegmentationDialog)
+QmitkConfirmSegmentationDialog::QmitkConfirmSegmentationDialog(QWidget *parent)
+  : QDialog(parent), m_Controls(new Ui::QmitkConfirmSegmentationDialog)
 {
   m_Controls->setupUi(this);
 
@@ -34,6 +45,6 @@ void QmitkConfirmSegmentationDialog::OnCancelSegmentation()
 
 void QmitkConfirmSegmentationDialog::SetSegmentationName(QString name)
 {
-  QString text ("Do you really want to overwrite "+name+"?");
+  QString text("Do you really want to overwrite " + name + "?");
   m_Controls->m_lblDialogText->setText(text);
 }
