@@ -15,6 +15,9 @@ found in the LICENSE file.
 #include <mitkMultiLabelEvents.h>
 #include <mitkRenderingManager.h>
 #include <mitkLabelSetImageHelper.h>
+#include <mitkSegChangeOperationApplier.h>
+
+#include <mitkSegChangeOperationApplier.h>
 
 #include <QmitkStyleManager.h>
 
@@ -51,6 +54,11 @@ public:
       m_childItems.push_back(child);
   };
 
+  void InsertChild(std::size_t row, QmitkMultiLabelSegTreeItem* child)
+  {
+    m_childItems.insert(m_childItems.begin()+row, child);
+  };
+
   void RemoveChild(std::size_t row)
   {
     if (row < m_childItems.size())
@@ -156,7 +164,7 @@ public:
     return nullptr;
   };
 
-  mitk::LabelSetImage::LabelValueType GetLabelValue() const
+  mitk::MultiLabelSegmentation::LabelValueType GetLabelValue() const
   {
     auto label = this->GetLabel();
 
@@ -169,14 +177,14 @@ public:
   };
 
   /** returns a vector containing all label values of referenced by this item or its child items.*/
-  std::vector< mitk::LabelSetImage::LabelValueType> GetLabelsInSubTree() const
+  std::vector< mitk::MultiLabelSegmentation::LabelValueType> GetLabelsInSubTree() const
   {
     if (this->m_ItemType == ItemType::Instance)
     {
       return { this->GetLabelValue() };
     }
 
-    std::vector< mitk::LabelSetImage::LabelValueType> result;
+    std::vector< mitk::MultiLabelSegmentation::LabelValueType> result;
     for (const auto child : this->m_childItems)
     {
       auto childresult = child->GetLabelsInSubTree();
@@ -271,14 +279,15 @@ QmitkMultiLabelSegTreeItem* GetLabelItemInGroup(const std::string& labelName, Qm
   return nullptr;
 }
 
-QmitkMultiLabelTreeModel::QmitkMultiLabelTreeModel(QObject *parent) : QAbstractItemModel(parent)
+QmitkMultiLabelTreeModel::QmitkMultiLabelTreeModel(QObject *parent) : QAbstractItemModel(parent), m_NearestLabelValueToLastChange(mitk::MultiLabelSegmentation::UNLABELED_VALUE)
 {
   m_RootItem = std::make_unique<QmitkMultiLabelSegTreeItem>();
 }
 
 QmitkMultiLabelTreeModel ::~QmitkMultiLabelTreeModel()
 {
-  this->SetSegmentation(nullptr);
+  this->m_Segmentation = nullptr;
+  this->AddObserver(); //removes current observers
 };
 
 int QmitkMultiLabelTreeModel::columnCount(const QModelIndex& /*parent*/) const
@@ -317,6 +326,20 @@ QVariant QmitkMultiLabelTreeModel::data(const QModelIndex &index, int role) cons
   if (!item)
     return QVariant();
 
+  // Safe guard: avoid accessing segmentation state mid-update
+  if (m_ModelUpdateOngoing)
+  {
+    switch (role)
+    {
+    case Qt::DisplayRole:
+    case Qt::EditRole:
+    case Qt::DecorationRole:
+      return QVariant();      // benign safe fallback
+    default:
+      break;
+    }
+  }
+
   if (role == Qt::DisplayRole||role == Qt::EditRole)
   {
     if (TableColumns::NAME_COL == index.column())
@@ -355,7 +378,7 @@ QVariant QmitkMultiLabelTreeModel::data(const QModelIndex &index, int role) cons
           if (nullptr == label)
             mitkThrow() << "Invalid internal state. QmitkMultiLabelTreeModel currentItem is referring to a label that does not exist.";
 
-          return QVariant(QString::fromStdString(label->GetName()) + QString(" [%1]").arg(item->GetLabelValue()));
+          return QVariant(QString::fromStdString(mitk::LabelSetImageHelper::CreateDisplayLabelName(m_Segmentation, label)));
         }
       }
     }
@@ -384,7 +407,7 @@ QVariant QmitkMultiLabelTreeModel::data(const QModelIndex &index, int role) cons
   {
     if (item->m_ItemType == QmitkMultiLabelSegTreeItem::ItemType::Group)
     {
-      return QVariant(QString("Group %1").arg(item->GetGroupID()));
+      return QVariant(QString("Group id: %1").arg(item->GetGroupID()));
     }
     else
     {
@@ -401,7 +424,44 @@ QVariant QmitkMultiLabelTreeModel::data(const QModelIndex &index, int role) cons
       }
       else
       {
-        name = QString::fromStdString(label->GetName()) + QString("\nLabel instance ID: %1\nPixel value: %2").arg(item->GetLabelValue()).arg(item->GetLabelValue());
+        name = QString::fromStdString(label->GetName());
+        name += QString("\nPixel value: %1").arg(item->GetLabelValue());
+        if (!label->GetTrackingID().empty())
+        {
+          name += QString("\nTracking ID: %1").arg(QString::fromStdString(label->GetTrackingID()));
+        }
+        if (label->GetAnatomicRegionCount()>0)
+        {
+          auto code = label->GetAnatomicRegion(0);
+          name += QString("\nAnatomic region: %1").arg(QString::fromStdString(code.GetMeaning()));
+        }
+        if (label->GetPrimaryAnatomicStructureCount() > 0)
+        {
+          auto code = label->GetPrimaryAnatomicStructure(0);
+          QString modifier = "";
+          if (code.GetModifierCount() > 0)
+          {
+            modifier = " (" + QString::fromStdString(code.GetModifier(0).GetMeaning()) + ")";
+          }
+          name += QString("\nPrimary anatomic structure: %1 %2").arg(QString::fromStdString(code.GetMeaning())).arg(modifier);
+        }
+        if (auto code = label->GetSegmentedPropertyCategory(); code.has_value())
+        {
+          name += QString("\nType category: %1").arg(QString::fromStdString(code->GetMeaning()));
+        }
+        if (auto code = label->GetSegmentedPropertyType(); code.has_value())
+        {
+          QString modifier = "";
+          if (code->GetModifierCount() > 0)
+          {
+            modifier = " (" + QString::fromStdString(code->GetModifier(0).GetMeaning()) + ")";
+          }
+          name += QString("\nType: %1 %2").arg(QString::fromStdString(code->GetMeaning())).arg(modifier);
+        }
+        if (!label->GetDescription().empty())
+        {
+          name += QString("\nDescription:\n%1").arg(QString::fromStdString(label->GetDescription()));
+        }
       }
       return QVariant(name);
     }
@@ -477,7 +537,9 @@ bool QmitkMultiLabelTreeModel::setData(const QModelIndex& index, const QVariant&
         }
         else if (TableColumns::COLOR_COL == index.column())
         {
+          mitk::SegLabelPropModifyUndoRedoHelper undoGenerator(m_Segmentation, { label->GetValue() });
           label->SetColor(QtToMitk(value.value<QColor>()));
+          undoGenerator.RegisterUndoRedoOperationEvent("Change color of \"" + mitk::LabelSetImageHelper::CreateDisplayLabelName(m_Segmentation, label) + "\"");
         }
         else if (TableColumns::VISIBLE_COL == index.column())
         {
@@ -494,6 +556,20 @@ bool QmitkMultiLabelTreeModel::setData(const QModelIndex& index, const QVariant&
       }
       return true;
     }
+    else //name column
+    {
+      if (item->m_ItemType == QmitkMultiLabelSegTreeItem::ItemType::Group)
+      {
+        auto groupID = item->GetGroupID();
+
+        mitk::SegGroupModifyUndoRedoHelper undoRedoGenerator(m_Segmentation, { groupID }, true, 0, true, true);
+        m_Segmentation->SetGroupName(groupID, value.toString().toStdString());
+        undoRedoGenerator.RegisterUndoRedoOperationEvent("Rename group #" + std::to_string(groupID));
+
+        m_Segmentation->Modified();
+        return true;
+      }
+    }
   }
   return false;
 }
@@ -517,7 +593,7 @@ QModelIndex QmitkMultiLabelTreeModel::index(int row, int column, const QModelInd
 
 QModelIndex QmitkMultiLabelTreeModel::indexOfLabel(mitk::Label::PixelType labelValue) const
 {
-  if (labelValue == mitk::LabelSetImage::UNLABELED_VALUE) return QModelIndex();
+  if (labelValue == mitk::MultiLabelSegmentation::UNLABELED_VALUE) return QModelIndex();
   auto relevantItem = GetInstanceItem(labelValue, this->m_RootItem.get());
 
   if (nullptr == relevantItem)
@@ -533,7 +609,7 @@ QModelIndex QmitkMultiLabelTreeModel::indexOfLabel(mitk::Label::PixelType labelV
   return GetIndexByItem(relevantItem, this);
 }
 
-QModelIndex QmitkMultiLabelTreeModel::indexOfGroup(mitk::LabelSetImage::GroupIndexType groupIndex) const
+QModelIndex QmitkMultiLabelTreeModel::indexOfGroup(mitk::MultiLabelSegmentation::GroupIndexType groupIndex) const
 {
   auto relevantItem = GetGroupItem(groupIndex, this->m_RootItem.get());
 
@@ -556,60 +632,6 @@ QModelIndex QmitkMultiLabelTreeModel::parent(const QModelIndex &child) const
   return createIndex(parentItem->Row(), 0, parentItem);
 }
 
-QModelIndex QmitkMultiLabelTreeModel::ClosestLabelInstanceIndex(const QModelIndex& currentIndex) const
-{
-  if (!currentIndex.isValid()) return QModelIndex();
-
-  auto currentItem = static_cast<const QmitkMultiLabelSegTreeItem*>(currentIndex.internalPointer());
-  if (!currentItem) return QModelIndex();
-
-  if (currentItem->RootItem() != this->m_RootItem.get()) mitkThrow() << "Invalid call. Passed currentIndex does not seem to be a valid index of this model. It is either outdated or from another model.";
-
-  const QmitkMultiLabelSegTreeItem* resultItem = nullptr;
-  auto searchItem = currentItem;
-  const auto rootItem = currentItem->RootItem();
-
-  while (searchItem != rootItem)
-  {
-    const auto* sibling = searchItem;
-
-    while (sibling != nullptr)
-    {
-      sibling = sibling->NextSibblingItem();
-      resultItem = GetFirstInstanceLikeItem(sibling);
-
-      if (nullptr != resultItem)
-        break;
-    }
-
-    if (nullptr != resultItem)
-      break;
-
-    // No next closest label instance on this level -> check for closest before
-    sibling = searchItem;
-
-    while (sibling != nullptr)
-    {
-      sibling = sibling->PrevSibblingItem();
-      resultItem = GetFirstInstanceLikeItem(sibling);
-
-      if (nullptr != resultItem)
-        break;
-    }
-
-    if (nullptr != resultItem)
-      break;
-
-    // No closest label instance before current on this level -> moeve one level up
-    searchItem = searchItem->ParentItem();
-  }
-
-  if (nullptr == resultItem)
-    return QModelIndex();
-
-  return GetIndexByItem(resultItem, this);
-}
-
 QModelIndex QmitkMultiLabelTreeModel::FirstLabelInstanceIndex(const QModelIndex& currentIndex) const
 {
   const QmitkMultiLabelSegTreeItem* currentItem = nullptr;
@@ -706,7 +728,7 @@ Qt::ItemFlags QmitkMultiLabelTreeModel::flags(const QModelIndex &index) const
       return Qt::ItemIsEnabled;
     }
   }
-  else
+  else //name column
   {
     if (item->HandleAsInstance())
     {
@@ -745,13 +767,13 @@ QVariant QmitkMultiLabelTreeModel::headerData(int section, Qt::Orientation orien
   return QVariant();
 }
 
-const mitk::LabelSetImage* QmitkMultiLabelTreeModel::GetSegmentation() const
+const mitk::MultiLabelSegmentation* QmitkMultiLabelTreeModel::GetSegmentation() const
 {
   return m_Segmentation;
 }
 
 
-void QmitkMultiLabelTreeModel::SetSegmentation(mitk::LabelSetImage* segmentation)
+void QmitkMultiLabelTreeModel::SetSegmentation(mitk::MultiLabelSegmentation* segmentation)
 {
   if (m_Segmentation != segmentation)
   {
@@ -809,7 +831,7 @@ void QmitkMultiLabelTreeModel::GenerateInternalGroupTree(unsigned int groupID, Q
 
   for (auto& label : labels)
   {
-    if (label->GetValue()== mitk::LabelSetImage::UNLABELED_VALUE) continue;
+    if (label->GetValue()== mitk::MultiLabelSegmentation::UNLABELED_VALUE) continue;
 
     bool newItemCreated = false;
     AddLabelToGroupTree(label, groupItem, newItemCreated);
@@ -822,7 +844,7 @@ QmitkMultiLabelSegTreeItem* QmitkMultiLabelTreeModel::GenerateInternalTree()
 
   if (m_Segmentation.IsNotNull())
   {
-    for (unsigned int groupID = 0; groupID < m_Segmentation->GetNumberOfLayers(); ++groupID)
+    for (unsigned int groupID = 0; groupID < m_Segmentation->GetNumberOfGroups(); ++groupID)
     {
       auto groupItem = new QmitkMultiLabelSegTreeItem(QmitkMultiLabelSegTreeItem::ItemType::Group, rootItem);
       rootItem->AppendChild(groupItem);
@@ -836,10 +858,12 @@ QmitkMultiLabelSegTreeItem* QmitkMultiLabelTreeModel::GenerateInternalTree()
 
 void QmitkMultiLabelTreeModel::UpdateInternalTree()
 {
+  m_ModelUpdateOngoing = true;
   emit beginResetModel();
   auto newTree = this->GenerateInternalTree();
   this->m_RootItem.reset(newTree);
   emit endResetModel();
+  m_ModelUpdateOngoing = false;
   emit modelChanged();
 }
 
@@ -905,13 +929,15 @@ void QmitkMultiLabelTreeModel::OnLabelAdded(LabelValueType labelValue)
   GroupIndexType groupIndex = m_Segmentation->GetGroupIndexOfLabel(labelValue);
   auto label = m_Segmentation->GetLabel(labelValue);
   if (label.IsNull()) mitkThrow() << "Invalid internal state. Segmentation signaled the addition of a label that does not exist in the segmentation. Invalid label value:" << labelValue;
-  if (labelValue == mitk::LabelSetImage::UNLABELED_VALUE) return;
+  if (labelValue == mitk::MultiLabelSegmentation::UNLABELED_VALUE) return;
 
   auto groupItem = GetGroupItem(groupIndex, this->m_RootItem.get());
 
   bool newLabelCreated = false;
   auto instanceItem = AddLabelToGroupTree(label, groupItem, newLabelCreated);
+  m_NearestLabelValueToLastChange = labelValue;
 
+  m_ModelUpdateOngoing = true;
   if (newLabelCreated)
   {
     if (groupItem->m_childItems.size() == 1)
@@ -947,22 +973,32 @@ void QmitkMultiLabelTreeModel::OnLabelAdded(LabelValueType labelValue)
       this->endInsertRows();
     }
   }
+  m_ModelUpdateOngoing = false;
+  emit modelChanged();
 }
 
 void QmitkMultiLabelTreeModel::OnLabelModified(LabelValueType labelValue)
 {
-  if (labelValue == mitk::LabelSetImage::UNLABELED_VALUE) return;
+  if (labelValue == mitk::MultiLabelSegmentation::UNLABELED_VALUE) return;
 
   auto instanceItem = GetInstanceItem(labelValue, this->m_RootItem.get());
 
   if (nullptr == instanceItem)
   {
     mitkThrow() << "Internal invalid state. QmitkMultiLabelTreeModel received a LabelModified signal for a label that is not represented in the model. Invalid label: " << labelValue;
-    mitkThrow() << "Internal invalid state. QmitkMultiLabelTreeModel received a LabelModified signal for a label that is not represented in the model. Invalid label: " << labelValue;
+  }
+
+  auto internalLabel = instanceItem->GetLabel();
+  auto segLabel = m_Segmentation->GetLabel(labelValue);
+  if (segLabel != internalLabel)
+  { //label instance has been changed in the segmentation instance
+    //we have to update internal pointer
+    instanceItem->m_Label = segLabel;
   }
 
   auto labelItem = instanceItem->ParentItem();
 
+  m_ModelUpdateOngoing = true;
   if (labelItem->m_ClassName == instanceItem->GetLabel()->GetName())
   { //only the state of the label changed, but not its position in the model tree.
     auto index = labelItem->HandleAsInstance() ? GetIndexByItem(labelItem, this) : GetIndexByItem(instanceItem, this);
@@ -974,18 +1010,81 @@ void QmitkMultiLabelTreeModel::OnLabelModified(LabelValueType labelValue)
     this->OnLabelRemoved(labelValue);
     this->OnLabelAdded(labelValue);
   }
+
+  m_NearestLabelValueToLastChange = labelValue;
+  m_ModelUpdateOngoing = false;
+  emit modelChanged();
+}
+
+const QmitkMultiLabelSegTreeItem* QmitkMultiLabelTreeModel::ClosestLabelInstanceIndex(const QmitkMultiLabelSegTreeItem* currentItem) const
+{
+  if (!currentItem) return nullptr;
+
+  if (currentItem->RootItem() != this->m_RootItem.get()) mitkThrow() << "Invalid call. Passed currentItem does not seem to be a valid index of this model. It is either outdated or from another model.";
+
+  const QmitkMultiLabelSegTreeItem* resultItem = nullptr;
+  auto searchItem = currentItem;
+  const auto rootItem = currentItem->RootItem();
+
+  while (searchItem != rootItem)
+  {
+    const auto* sibling = searchItem;
+
+    while (sibling != nullptr)
+    {
+      sibling = sibling->NextSibblingItem();
+      resultItem = GetFirstInstanceLikeItem(sibling);
+
+      if (nullptr != resultItem)
+        break;
+    }
+
+    if (nullptr != resultItem)
+      break;
+
+    // No next closest label instance on this level -> check for closest before
+    sibling = searchItem;
+
+    while (sibling != nullptr)
+    {
+      sibling = sibling->PrevSibblingItem();
+      resultItem = GetFirstInstanceLikeItem(sibling);
+
+      if (nullptr != resultItem)
+        break;
+    }
+
+    if (nullptr != resultItem)
+      break;
+
+    // No closest label instance before current on this level -> move one level up
+    searchItem = searchItem->ParentItem();
+  }
+
+  return resultItem;
 }
 
 void QmitkMultiLabelTreeModel::OnLabelRemoved(LabelValueType labelValue)
 {
-  if (labelValue == mitk::LabelSetImage::UNLABELED_VALUE) return;
+  if (labelValue == mitk::MultiLabelSegmentation::UNLABELED_VALUE) return;
   auto instanceItem = GetInstanceItem(labelValue, this->m_RootItem.get());
 
   if (nullptr == instanceItem)
     mitkThrow() << "Internal invalid state. QmitkMultiLabelTreeModel received a LabelRemoved signal for a label that is not represented in the model. Invalid label: " << labelValue;
 
+  const auto nextItem = ClosestLabelInstanceIndex(instanceItem);
+  if (nullptr != nextItem)
+  {
+    m_NearestLabelValueToLastChange = nextItem->GetLabelValue();
+  }
+  else
+  {
+    m_NearestLabelValueToLastChange = mitk::MultiLabelSegmentation::UNLABELED_VALUE;
+  }
+
   auto labelItem = instanceItem->ParentItem();
 
+  m_ModelUpdateOngoing = true;
   if (labelItem->m_childItems.size() > 2)
   {
     auto labelIndex = GetIndexByItem(labelItem, this);
@@ -1009,34 +1108,53 @@ void QmitkMultiLabelTreeModel::OnLabelRemoved(LabelValueType labelValue)
     groupItem->RemoveChild(labelItem->Row());
     this->endRemoveRows();
   }
+  m_ModelUpdateOngoing = false;
+  emit modelChanged();
 }
 
 void QmitkMultiLabelTreeModel::OnGroupAdded(GroupIndexType groupIndex)
 {
   if (m_ShowGroups)
   {
+    m_ModelUpdateOngoing = true;
     this->beginInsertRows(QModelIndex(), groupIndex, groupIndex);
     auto rootItem = m_RootItem.get();
     auto groupItem = new QmitkMultiLabelSegTreeItem(QmitkMultiLabelSegTreeItem::ItemType::Group, rootItem);
-    rootItem->AppendChild(groupItem);
+    rootItem->InsertChild(groupIndex, groupItem);
     this->GenerateInternalGroupTree(groupIndex, groupItem);
     this->endInsertRows();
+    m_ModelUpdateOngoing = false;
+    emit modelChanged();
   }
 }
 
-void QmitkMultiLabelTreeModel::OnGroupModified(GroupIndexType /*groupIndex*/)
+void QmitkMultiLabelTreeModel::OnGroupModified(GroupIndexType groupIndex)
 {
-  //currently not needed
+  if (m_ShowGroups)
+  {
+    if (m_Segmentation->ExistGroup(groupIndex))
+    {
+      m_ModelUpdateOngoing = true;
+      auto groupItem = GetGroupItem(groupIndex, m_RootItem.get());
+      auto modelIndex = GetIndexByItem(groupItem, this);
+      emit dataChanged(modelIndex, modelIndex);
+      m_ModelUpdateOngoing = false;
+      emit modelChanged();
+    }
+  }
 }
 
 void QmitkMultiLabelTreeModel::OnGroupRemoved(GroupIndexType groupIndex)
 {
   if (m_ShowGroups)
   {
+    m_ModelUpdateOngoing = true;
     this->beginRemoveRows(QModelIndex(), groupIndex, groupIndex);
     auto root = m_RootItem.get();
     root->RemoveChild(groupIndex);
     this->endRemoveRows();
+    m_ModelUpdateOngoing = false;
+    emit modelChanged();
   }
 }
 
@@ -1059,3 +1177,13 @@ bool QmitkMultiLabelTreeModel::GetAllowLockModification() const
 {
   return m_AllowLockModification;
 }
+
+bool QmitkMultiLabelTreeModel::GetModelUpdateOngoing() const
+{
+  return m_ModelUpdateOngoing;
+}
+
+QmitkMultiLabelTreeModel::LabelValueType QmitkMultiLabelTreeModel::GetNearestLabelValueToLastChange() const
+{
+  return m_NearestLabelValueToLastChange;
+}
