@@ -13,6 +13,7 @@ found in the LICENSE file.
 #ifndef QmitkSegmentationTaskListWidget_h
 #define QmitkSegmentationTaskListWidget_h
 
+#include <mitkForm.h>
 #include <mitkSegmentationTaskList.h>
 
 #include <MitkSegmentationUIExports.h>
@@ -43,7 +44,7 @@ public:
 
   bool ActiveTaskIsShown() const;
   void LoadNextUnfinishedTask();
-  void SaveActiveTask(bool saveAsIntermediateResult = false);
+  void SaveActiveTask(bool saveAsInterimResult = false);
   bool OnPreShutdown();
 
 signals:
@@ -65,6 +66,8 @@ private:
   void UpdateLoadButton();
   void UpdateNavigationButtons();
   void UpdateDetailsLabel();
+  void UpdateFormWidget();
+  void OnFormSubmission();
   void UpdateStoreAndAcceptButtons();
   void OnLoadButtonClicked();
   mitk::DataNode* GetImageDataNode(size_t index) const;
@@ -76,7 +79,6 @@ private:
   void SetActiveTaskIndex(const std::optional<size_t>& index);
   void SetCurrentTaskIndex(const std::optional<size_t>& index);
   bool HandleUnsavedChanges(const QString& alternativeTitle = QString());
-  mitk::DataNode* GetSegmentationDataNode(size_t index) const;
   void OnUnsavedChangesSaved();
   void OnPreviousTaskShortcutActivated();
   void OnNextTaskShortcutActivated();
@@ -91,7 +93,10 @@ private:
   QFileSystemWatcher* m_FileSystemWatcher;
   mitk::DataStorage* m_DataStorage;
   mitk::SegmentationTaskList::Pointer m_TaskList;
+  mitk::Forms::Form m_Form;
   mitk::DataNode::Pointer m_TaskListNode;
+  mitk::DataNode* m_ImageNode;
+  mitk::DataNode* m_SegmentationNode;
   std::optional<size_t> m_CurrentTaskIndex;
   std::optional<size_t> m_ActiveTaskIndex;
   std::optional<unsigned long> m_SegmentationModifiedObserverTag;
