@@ -14,11 +14,12 @@ found in the LICENSE file.
 #define QmitkToolGUI_h
 
 #include <MitkSegmentationUIExports.h>
-#include <qwidget.h>
 
 #include "mitkCommon.h"
 #include "mitkTool.h"
 
+#include <QWidget>
+
 /**
   \brief Base class for GUIs belonging to mitk::Tool classes.
 
