@@ -10,7 +10,6 @@ found in the LICENSE file.
 
 ============================================================================*/
 
-#include <QApplication>
 #include <QColor>
 #include "QmitkMultiLabelTreeModel.h"
 
@@ -31,16 +30,13 @@ class QmitkMultiLabelTreeModelTestSuite : public mitk::TestFixture
 
   CPPUNIT_TEST_SUITE_END();
 
-  mitk::LabelSetImage::Pointer m_Segmentation;
-
-  QCoreApplication* m_TestApp;
+  mitk::MultiLabelSegmentation::Pointer m_Segmentation;
 
 public:
-
-  mitk::LabelSetImage::Pointer GenerateSegmentation()
+  mitk::MultiLabelSegmentation::Pointer GenerateSegmentation()
   {
     // Create a new labelset image
-    auto seg = mitk::LabelSetImage::New();
+    auto seg = mitk::MultiLabelSegmentation::New();
     mitk::Image::Pointer regularImage = mitk::Image::New();
     unsigned int dimensions[3] = { 5, 5, 5 };
     regularImage->Initialize(mitk::MakeScalarPixelType<char>(), 3, dimensions);
@@ -77,16 +73,14 @@ public:
   *  - Label B
   *   - Instance 9 (6)
   */
-  void PopulateSegmentation(mitk::LabelSetImage* seg)
+  void PopulateSegmentation(mitk::MultiLabelSegmentation* seg)
   {
-    seg->SetActiveLayer(0);
-
     seg->AddLabel(CreateLabel("A", 1),0);
     seg->AddLabel(CreateLabel("A", 5),0);
     seg->AddLabel(CreateLabel("B", 4),0);
 
-    seg->AddLayer();
-    seg->AddLayer();
+    seg->AddGroup();
+    seg->AddGroup();
 
     seg->AddLabel(CreateLabel("B", 9),2);
 
@@ -99,15 +93,10 @@ public:
     m_Segmentation = GenerateSegmentation();
 
     PopulateSegmentation(m_Segmentation);
-
-    int argc = 0;
-    char** argv = nullptr;
-    m_TestApp = new QCoreApplication(argc, argv);
   }
 
   void tearDown() override
   {
-    delete m_TestApp;
   }
 
   QModelIndex GetIndex(const QmitkMultiLabelTreeModel& model, const std::vector<int>& rows, int column = 0) const
@@ -217,8 +206,7 @@ public:
     QmitkMultiLabelTreeModel model(nullptr);
     model.SetSegmentation(m_Segmentation);
 
-    //Add label instance (not visible) to labelwith multiple instances (at the end)
-    m_Segmentation->SetActiveLayer(0);
+    //Add label instance (not visible) to label with multiple instances (at the end)
     auto newLabel = CreateLabel("A", 100);
     newLabel->SetVisible(false);
     m_Segmentation->AddLabel(newLabel,0);
@@ -242,7 +230,6 @@ public:
     CheckModelGroup2Default(model);
 
     //Add label instance (not locked) to label with multiple instances (in between)
-    m_Segmentation->SetActiveLayer(0);
     newLabel = CreateLabel("A", 7);
     newLabel->SetLocked(false);
     m_Segmentation->AddLabel(newLabel,0);
@@ -272,7 +259,6 @@ public:
     model.SetSegmentation(m_Segmentation);
 
     //Add label instance to an empty group
-    m_Segmentation->SetActiveLayer(1);
     newLabel = CreateLabel("A", 3);
     m_Segmentation->AddLabel(newLabel,1);
 
@@ -291,7 +277,7 @@ public:
     QmitkMultiLabelTreeModel model(nullptr);
     model.SetSegmentation(m_Segmentation);
 
-    m_Segmentation->AddLayer();
+    m_Segmentation->AddGroup();
 
     CPPUNIT_ASSERT_EQUAL(4, model.rowCount(QModelIndex()));
     CheckModelGroup0Default(model);
@@ -333,7 +319,7 @@ public:
   {
     QmitkMultiLabelTreeModel model(nullptr);
     model.SetSegmentation(m_Segmentation);
-    //remove label instance from label with multiple instances (middel)
+    //remove label instance from label with multiple instances (middle)
     m_Segmentation->RemoveLabel(5);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
     CPPUNIT_ASSERT(CheckModelRow(model, { 0 }, { QString("Group 1"), QVariant(), QVariant(), QVariant() }));
@@ -550,7 +536,6 @@ public:
     CPPUNIT_ASSERT_EQUAL(0, model.rowCount(GetIndex(model, { 2,0 })));
 
     //check instance modifications with multi instance label
-    m_Segmentation->SetActiveLayer(2);
     m_Segmentation->AddLabel(CreateLabel("B", 33),2);
     label->SetVisible(true);
     CPPUNIT_ASSERT_EQUAL(3, model.rowCount(QModelIndex()));
