@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYCOMMANDMANAGER_H_
 #define BERRYCOMMANDMANAGER_H_
@@ -173,7 +169,7 @@ public:
   /**
    * Sets the name and description of the category for uncategorized commands.
    * This is the category that will be returned if
-   * {@link #getCategory(String)} is called with <code>null</code>.
+   * {@link #GetCategory} is called with <code>null</code>.
    *
    * @param name
    *            The name of the category for uncategorized commands; must not
@@ -191,7 +187,7 @@ public:
    * parameterizations as specified in the provided
    * <code>serializedParameterizedCommand</code> string. The
    * <code>serializedParameterizedCommand</code> must use the format
-   * returned by {@link ParameterizedCommand#serialize()} and described in the
+   * returned by {@link ParameterizedCommand#Serialize} and described in the
    * Javadoc for that method.
    * </p>
    * <p>
