@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYCOMPOSITEEXPRESSION_H_
 #define BERRYCOMPOSITEEXPRESSION_H_
@@ -45,7 +41,7 @@ protected:
   virtual EvaluationResult::ConstPointer EvaluateAnd(IEvaluationContext* scope) const;
   virtual EvaluationResult::ConstPointer EvaluateOr(IEvaluationContext* scope) const;
 
-  virtual uint ComputeHashCode() const override;
+  uint ComputeHashCode() const override;
 
 public:
 
@@ -53,7 +49,7 @@ public:
 
   virtual QList<Expression::Pointer> GetChildren();
 
-  virtual void CollectExpressionInfo(ExpressionInfo* info) const override;
+  void CollectExpressionInfo(ExpressionInfo* info) const override;
 
 };
 
