@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryExtensionsParser.h"
 
@@ -30,7 +26,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include "berryRegistryObjectFactory.h"
 #include "berryRegistryObjectManager.h"
 
-#include <QTime>
+#include <QElapsedTimer>
 
 namespace berry {
 
@@ -231,17 +227,17 @@ ExtensionsParser::parseManifest(QXmlReader* reader, QXmlInputSource* in,
                                 const SmartPointer<RegistryContribution>& currentNamespace,
                                 QTranslator* translator)
 {
-  QTime start;
+  QElapsedTimer timer;
   this->resources = translator;
   this->objectManager = registryObjects;
   //initialize the parser with this object
   this->contribution = currentNamespace;
   if (registry->Debug())
-    start.start();
+    timer.start();
 
   if (reader == nullptr)
   {
-    cumulativeTime += start.elapsed();
+    cumulativeTime += timer.elapsed();
     throw ctkInvalidArgumentException("XML Reader not available");
   }
 
@@ -256,7 +252,7 @@ ExtensionsParser::parseManifest(QXmlReader* reader, QXmlInputSource* in,
 
   if (registry->Debug())
   {
-    cumulativeTime += start.elapsed();
+    cumulativeTime += timer.elapsed();
     BERRY_INFO << "Cumulative parse time so far : " << cumulativeTime;
   }
 
