@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #ifndef BERRYIEXTENSIONREGISTRY_H
@@ -23,6 +19,7 @@ See LICENSE.txt or http://www.mitk.org for details.
 #include <berrySmartPointer.h>
 
 #include <QList>
+#include <QtPlugin>
 
 class QTranslator;
 
@@ -48,7 +45,7 @@ struct IRegistryEventListener;
  * are intended for relatively short-term use. Clients that deal with these objects
  * must be aware that they may become invalid if the declaring plug-in is updated
  * or uninstalled. If this happens, all methods on these object except
- * <code>isValid()</code> will throw {@link org.eclipse.core.runtime.InvalidRegistryObjectException}.
+ * <code>isValid()</code> will throw {@link InvalidRegistryObjectException}.
  * Code in a plug-in that has declared that it is not dynamic aware (or not declared
  * anything) can safely ignore this issue, since the registry would not be
  * modified while it is active. However, code in a plug-in that declares that it
@@ -65,13 +62,12 @@ struct IRegistryEventListener;
  * </p>
  * <p>
  * Extensions and extension points are declared by generic entities called
- * <cite>namespaces</cite>. The only fact known about namespaces is that they
+ * \c namespaces . The only fact known about namespaces is that they
  * have unique string-based identifiers. One example of a namespace
  * is a plug-in, for which the namespace id is the plug-in id.
  * </p><p>
  * This interface is not intended to be implemented by clients.
  * </p>
- * @noimplement This interface is not intended to be implemented by clients.
  */
 struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
 {
@@ -97,7 +93,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * point does not exist, has no extensions configured, or none of the extensions
    * contain configuration elements.
    *
-   * @param namespace the namespace for the extension point
+   * @param namespaze the namespace for the extension point
    *    (e.g. <code>"org.eclipse.core.resources"</code>)
    * @param extensionPointName the simple identifier of the
    *    extension point (e.g. <code>"builders"</code>)
@@ -111,7 +107,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * Returns an empty array if the extension does not exist or
    * contains no configuration elements.
    *
-   * @param namespace the namespace for the extension point
+   * @param namespaze the namespace for the extension point
    *    (e.g. <code>"org.eclipse.core.resources"</code>)
    * @param extensionPointName the simple identifier of the
    *    extension point (e.g. <code>"builders"</code>)
@@ -153,7 +149,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * The first two parameters identify the extension point, and the third
    * parameter identifies an extension plugged in to that extension point.
    *
-   * @param namespace the namespace for the extension point
+   * @param namespaze the namespace for the extension point
    *    (e.g. <code>"org.eclipse.core.resources"</code>)
    * @param extensionPointName the simple identifier of the
    *    extension point (e.g. <code>"builders"</code>)
@@ -181,7 +177,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * with the given namespace and extension point simple identifier,
    * or <code>null</code> if there is no such extension point.
    *
-   * @param namespace the namespace for the given extension point
+   * @param namespaze the namespace for the given extension point
    *    (e.g. <code>"org.eclipse.core.resources"</code>)
    * @param extensionPointName the simple identifier of the
    *    extension point (e.g. <code>"builders"</code>)
@@ -202,7 +198,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * Returns all extension points declared in the given namespace. Returns an empty array if
    * there are no extension points declared in the namespace.
    *
-   * @param namespace the namespace for the extension points
+   * @param namespaze the namespace for the extension points
    *    (e.g. <code>"org.eclipse.core.resources"</code>)
    * @return the extension points in this registry declared in the given namespace
    */
@@ -224,7 +220,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * Returns all extensions declared in the given namespace. Returns an empty array if
    * no extensions are declared in the namespace.
    *
-   * @param namespace the namespace for the extensions
+   * @param namespaze the namespace for the extensions
    *    (e.g. <code>"org.eclipse.core.resources"</code>)
    * @return the extensions in this registry declared in the given namespace
    */
@@ -262,8 +258,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * editor) is ignored by this method.
    * <p>
    * This method is an access controlled method. Proper token (master token or user token) should
-   * be passed as an argument. Two registry keys are set in the registry constructor
-   * {@link RegistryFactory#CreateRegistry(RegistryStrategy*, QObject*, QObject*)}:
+   * be passed as an argument. Two registry keys are set in the registry constructor:
    * master token and a user token. Master token allows all operations; user token allows
    * non-persisted registry elements to be modified.
    * </p>
@@ -275,7 +270,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * @param persist indicates if the contribution(s) should be stored in the registry cache. If <code>false</code>,
    *        contribution is not persisted in the registry cache and is lost on BlueBerry restart
    * @param name optional name of the contribution. Used for error reporting; might be <code>QString()</code>
-   * @param translationBundle optional translator used for translations; might be <code>NULL</code>
+   * @param translationBundle optional translator used for translations; might be <code>nullptr</code>
    * @param token the key used to check permissions
    * @return <code>true</code> if the contribution was successfully processed and <code>false</code> otherwise
    * @throws ctkInvalidArgumentException if an incorrect token is passed
@@ -289,8 +284,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * Removes the given extension from this registry.
    * <p>
    * This method is an access controlled method. Proper token (master token or user token) should
-   * be passed as an argument. Two registry keys are set in the registry constructor
-   * {@link RegistryFactory#CreateRegistry(RegistryStrategy*, QObject*, QObject*)}:
+   * be passed as an argument. Two registry keys are set in the registry constructor:
    * master token and a user token. Master token allows all operations; user token only
    * allows non-persisted registry elements to be modified.
    * </p>
@@ -306,8 +300,7 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * Removes the specified extension point from this registry.
    * <p>
    * This method is an access controlled method. Proper token (master token or user token) should
-   * be passed as an argument. Two registry keys are set in the registry constructor
-   * {@link RegistryFactory#CreateRegistry(RegistryStrategy*, QObject*, QObject*)}:
+   * be passed as an argument. Two registry keys are set in the registry constructor:
    * master token and a user token. Master token allows all operations; user token only
    * allows non-persisted registry elements to be modified.
    * </p>
@@ -327,7 +320,6 @@ struct org_blueberry_core_runtime_EXPORT IExtensionRegistry
    * <p>
    * This method is an access controlled method. Master token should be passed as an argument.
    * </p>
-   * @see RegistryFactory#CreateRegistry(RegistryStrategy*, QObject*, QObject*)
    * @param token master token for the registry
    * @throws IllegalArgumentException if incorrect token is passed
    */
