@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYINVALIDREGISTRYOBJECTEXCEPTION_H
 #define BERRYINVALIDREGISTRYOBJECTEXCEPTION_H
@@ -31,15 +27,13 @@ namespace berry {
  * objects. It is not intended to be instantiated or
  * subclassed by clients.
  * </p>
- * @noinstantiate This class is not intended to be instantiated by clients.
- * @noextend This class is not intended to be subclassed by clients.
  */
 class org_blueberry_core_runtime_EXPORT InvalidRegistryObjectException : public ctkRuntimeException
 {
 public:
 
   InvalidRegistryObjectException();
-  ~InvalidRegistryObjectException() throw();
+  ~InvalidRegistryObjectException() throw() override;
 
   const char* name() const throw() override;
   InvalidRegistryObjectException* clone() const override;
