@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYQHELPENGINEWRAPPER_H
 #define BERRYQHELPENGINEWRAPPER_H
@@ -30,7 +26,7 @@ class QHelpEngineWrapper : public QHelpEngine
 public:
 
   QHelpEngineWrapper(const QString &collectionFile);
-  ~QHelpEngineWrapper();
+  ~QHelpEngineWrapper() override;
 
   /*
    * To be called after the initial search for qch files finished.
