@@ -1,24 +1,19 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYLOGPLUGIN_H_
 #define BERRYLOGPLUGIN_H_
 
 #include <ctkPluginActivator.h>
-
 #include "berryQtPlatformLogModel.h"
 
 
@@ -27,9 +22,7 @@ namespace berry {
 class QtLogPlugin : public QObject, public ctkPluginActivator
 {
   Q_OBJECT
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
   Q_PLUGIN_METADATA(IID "org_blueberry_ui_qt_log")
-#endif
   Q_INTERFACES(ctkPluginActivator)
 
 public:
