@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
 #ifndef BERRYIFOLDERLAYOUT_H_
@@ -32,14 +28,13 @@ namespace berry {
  * </p>
  *
  * @see IPageLayout#createFolder
- * @noimplement This interface is not intended to be implemented by clients.
  */
 struct BERRY_UI_QT IFolderLayout : public IPlaceholderFolderLayout
 {
 
-  berryObjectMacro(berry::IFolderLayout)
+  berryObjectMacro(berry::IFolderLayout);
 
-  ~IFolderLayout();
+  ~IFolderLayout() override;
 
     /**
      * Adds a view with the given compound id to this folder.
