@@ -1,24 +1,19 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIPERSISTABLE_H
 #define BERRYIPERSISTABLE_H
 
 #include <org_blueberry_ui_qt_Export.h>
-
 #include <berrySmartPointer.h>
 
 namespace berry {
@@ -44,4 +39,3 @@ struct BERRY_UI_QT IPersistable
 }
 
 #endif // BERRYIPERSISTABLE_H
-
