@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYIWORKBENCHPAGE_H_
 #define BERRYIWORKBENCHPAGE_H_
@@ -69,17 +65,16 @@ struct IExtensionTracker;
 struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionService, public Object
 {
 
-  berryObjectMacro(berry::IWorkbenchPage)
+  berryObjectMacro(berry::IWorkbenchPage);
 
-  ~IWorkbenchPage();
+  ~IWorkbenchPage() override;
 
   /**
    * An optional attribute within a workspace marker (<code>IMarker</code>)
    * which identifies the preferred editor type to be opened when
    * <code>openEditor</code> is called.
    *
-   * @see #openEditor(IEditorInput, String)
-   * @see #openEditor(IEditorInput, String, boolean)
+   * @see #OpenEditor
    * @deprecated in 3.0 since the notion of markers this is not generally
    *             applicable. Use the IDE-specific constant
    *             <code>IDE.EDITOR_ID_ATTR</code>.
@@ -161,7 +156,7 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
   /**
    * Show view mode that indicates the view should be made visible and
    * activated. Use of this mode has the same effect as calling
-   * {@link #showView(String)}.
+   * #ShowView .
    */
   static const int VIEW_ACTIVATE; // = 1;
 
@@ -207,14 +202,6 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    */
   virtual void Activate(IWorkbenchPart::Pointer part) = 0;
 
-  /**
-   * Adds a property change listener.
-   *
-   * @param listener
-   *            the property change listener to add
-   */
-  //virtual void addPropertyChangeListener(IPropertyChangeListener listener);
-
   /**
    * Moves the given part forward in the Z order of this page so as to make it
    * visible, without changing which part has focus. The part must belong to
@@ -375,7 +362,7 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    *
    * @return a list of open editors
    *
-   * @deprecated use #getEditorReferences() instead
+   * @deprecated use #GetEditorReferences instead
    */
   virtual QList<IEditorPart::Pointer> GetEditors() = 0;
 
@@ -417,8 +404,8 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    * <code>null</code> if there is no current perspective.
    *
    * @return the current perspective descriptor or <code>null</code>
-   * @see #setPerspective
-   * @see #savePerspective
+   * @see #SetPerspective
+   * @see #SavePerspective
    */
   virtual IPerspectiveDescriptor::Pointer GetPerspective() = 0;
 
@@ -442,7 +429,7 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    *
    * @return a list of visible views
    *
-   * @deprecated use #getViewReferences() instead.
+   * @deprecated use #GetViewReferences() instead.
    */
   virtual QList<IViewPart::Pointer> GetViews() = 0;
 
@@ -483,14 +470,6 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    */
   virtual bool IsPartVisible(IWorkbenchPart::Pointer part) = 0;
 
-  /**
-   * Removes the perspective specified by desc.
-   *
-   * @param desc
-   *            the perspective that will be removed
-   */
-  //virtual void RemovePerspective(IPerspectiveDescriptor::Pointer desc) = 0;
-
   /**
    * Reuses the specified editor by setting its new input.
    *
@@ -538,7 +517,7 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    * If this page already has an editor open on the target input that editor
    * is brought to the front; otherwise, a new editor is opened. Two editor
    * inputs are considered the same if they equal. See
-   * <code>Object.equals(Object)<code>
+   * <code>Object.equals(Object)</code>
    * and <code>IEditorInput</code>. If <code>activate == true</code> the editor
    * will be activated.
    * </p><p>
@@ -566,7 +545,7 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    * and/or editor id (as specified by the matchFlags argument), that editor
    * is brought to the front; otherwise, a new editor is opened. Two editor
    * inputs are considered the same if they equal. See
-   * <code>Object.equals(Object)<code>
+   * <code>Object.equals(Object)</code>
    * and <code>IEditorInput</code>. If <code>activate == true</code> the editor
    * will be activated.
    * </p><p>
@@ -592,14 +571,6 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
   virtual IEditorPart::Pointer OpenEditor(IEditorInput::Pointer input,
       const QString& editorId, bool activate, int matchFlags) = 0;
 
-  /**
-   * Removes the property change listener.
-   *
-   * @param listener
-   *            the property change listener to remove
-   */
-  //virtual void removePropertyChangeListener(IPropertyChangeListener listener);
-
   /**
    * Changes the visible views, their layout, and the visible action sets
    * within the page to match the current perspective descriptor. This is a
@@ -797,17 +768,6 @@ struct BERRY_UI_QT IWorkbenchPage : public IPartService, public ISelectionServic
    */
   virtual QList<IPerspectiveDescriptor::Pointer> GetSortedPerspectives() = 0;
 
-  /**
-   * Closes current perspective. If last perspective, then entire page
-   * is closed.
-   *
-   * @param saveParts
-   *            whether the page's parts should be saved if closed
-   * @param closePage
-   *            whether the page itself should be closed if last perspective
-   */
-  //virtual void CloseCurrentPerspective(bool saveParts, bool closePage) = 0;
-
   /**
    * Closes the specified perspective in this page. If the last perspective in
    * this page is closed, then all editors are closed. Views that are not
