@@ -23,6 +23,8 @@ found in the LICENSE file.
 
 #include "services/berryIServiceLocator.h"
 
+#include <QToolBar>
+
 namespace berry {
 
 struct IPartService;
@@ -59,7 +61,7 @@ struct IWorkbench;
  * @see IWorkbenchPage
  *
  */
-struct BERRY_UI_QT IWorkbenchWindow : public IPageService, public IServiceLocator, public virtual Object
+struct BERRY_UI_QT IWorkbenchWindow : public IPageService, public IServiceLocator /** \cond */, public virtual Object /** \endcond */
 {
 
   berryObjectMacro(berry::IWorkbenchWindow, IPageService, IServiceLocator, Object);
@@ -133,6 +135,11 @@ struct BERRY_UI_QT IWorkbenchWindow : public IPageService, public IServiceLocato
    */
   virtual IWorkbench* GetWorkbench() const = 0;
 
+  /**
+   * Returns all tool bars for this window.
+   */
+  virtual QList<QToolBar*> GetToolBars() const = 0;
+
   /**
    * Creates and opens a new workbench page. The perspective of the new page
    * is defined by the specified perspective ID. The new page become active.
