@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef BERRYWINDOW_H_
 #define BERRYWINDOW_H_
@@ -88,13 +84,13 @@ class BERRY_UI_QT Window: public IShellProvider
 
 public:
 
-  berryObjectMacro(Window, IShellProvider)
+  berryObjectMacro(Window, IShellProvider);
 
   /**
    * Standard return code constant (value 0) indicating that the window was
    * opened.
    *
-   * @see #open
+   * @see #Open
    */
   static const int OK; // = 0;
 
@@ -102,7 +98,7 @@ public:
    * Standard return code constant (value 1) indicating that the window was
    * canceled.
    *
-   * @see #open
+   * @see #Open
    */
   static const int CANCEL; // = 1;
 
@@ -119,13 +115,13 @@ public:
   struct IExceptionHandler: public Object
   {
 
-    berryObjectMacro(IExceptionHandler)
+    berryObjectMacro(IExceptionHandler);
 
     /**
      * Handle the exception.
      *
      * @param t
-     *            The exception that occured.
+     *            The exception that occurred.
      */
     virtual void HandleException(const std::exception& t) = 0;
   };
@@ -160,24 +156,10 @@ private:
   /**
    * Menu bar manager, or <code>null</code> if none (default).
    *
-   * @see #addMenuBar
+   * @see #AddMenuBar
    */
   SmartPointer<MenuManager> menuBarManager;
 
-  /**
-   * Tool bar manager, or <code>null</code> if none (default).
-   *
-   * @see #addToolBar
-   */
-  //SmartPointer<IToolBarManager> toolBarManager;
-
-  /**
-   * Status line manager, or <code>null</code> if none (default).
-   *
-   * @see #addStatusLine
-   */
-  //SmartPointer<StatusLineManager> statusLineManager;
-
   /**
    * The exception handler for this application.
    */
@@ -241,28 +223,6 @@ private:
    */
   bool block; // = false;
 
-  //  /**
-  //   * Internal class for informing this window when fonts change.
-  //   */
-  //  class FontChangeListener implements IPropertyChangeListener {
-  //    public void propertyChange(PropertyChangeEvent event) {
-  //      handleFontChange(event);
-  //    }
-  //  }
-
-  //  /**
-  //   * Internal font change listener.
-  //   */
-  //  private FontChangeListener fontChangeListener;
-
-  /**
-   * Internal fields to detect if shell size has been set
-   */
-  //bool resizeHasOccurred = false;
-
-  //Listener resizeListener;
-
-
   /**
    * Returns the most specific modal child from the given list of Shells.
    *
@@ -274,14 +234,6 @@ private:
   static Shell::Pointer GetModalChild(
       const QList<Shell::Pointer>& toSearch);
 
-  /**
-   * Runs the event loop for the given shell.
-   *
-   * @param loopShell
-   *            the shell
-   */
-  //void RunEventLoop();
-
 protected:
 
   /**
@@ -293,8 +245,7 @@ protected:
    *            the parent shell, or <code>null</code> to create a top-level
    *            shell. Try passing "(Shell)null" to this method instead of "null"
    *            if your compiler complains about an ambiguity error.
-   * @see #setBlockOnOpen
-   * @see #getDefaultOrientation()
+   * @see #SetBlockOnOpen
    */
   Window(Shell::Pointer parentShell);
 
@@ -307,7 +258,7 @@ protected:
    */
   Window(IShellProvider::Pointer shellProvider);
 
-  ~Window();
+  ~Window() override;
 
   /**
    * Given the desired position of the window, this method returns an adjusted
@@ -354,13 +305,6 @@ protected:
    */
   virtual void ConfigureShell(Shell::Pointer newShell);
 
-  /**
-   * Constrain the shell size to be no larger than the display bounds.
-   *
-   * @since 2.0
-   */
-  //void ConstrainShellSize();
-
   /**
    * Creates and returns this window's contents. Subclasses may attach any
    * number of children to the parent. As a convenience, the return value of
@@ -369,7 +313,7 @@ protected:
    * getLayout() to return null.
    *
    * <p>
-   * It is common practise to create and return a single composite that
+   * It is common practice to create and return a single composite that
    * contains the entire window contents.
    * </p>
    *
@@ -588,7 +532,7 @@ public:
    * default image unless one is installed via <code>setDefaultImage</code>.
    *
    * @return the default image, or <code>null</code> if none
-   * @see #setDefaultImage
+   * @see #SetDefaultImage
    */
   static QIcon GetDefaultImage();
 
@@ -600,7 +544,7 @@ public:
    * @see org.blueberry.swt.widgets.Decorations#setImages(org.blueberry.swt.graphics.Image[])
    *
    * @return the array of images to be used when a new window is opened
-   * @see #setDefaultImages
+   * @see #SetDefaultImages
    * @since 3.0
    */
   static QList<QIcon> GetDefaultImages();
@@ -634,7 +578,7 @@ public:
    *
    * @return the menu bar manager, or <code>null</code> if
    *   this window does not have a menu bar
-   * @see #addMenuBar()
+   * @see #AddMenuBar()
    */
   MenuManager* GetMenuBarManager() const;
 
@@ -651,7 +595,7 @@ public:
    *
    * @return the return code
    *
-   * @see #create()
+   * @see #Create()
    */
   int Open();
 
