@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "berryEditorRegistry.h"
 
@@ -846,7 +842,7 @@ bool EditorRegistry::LoadAssociations()
 
 QString EditorRegistry::MappingKeyFor(const QString& type)
 {
-  // keep everyting lower case for case-sensitive platforms
+  // keep everything lower case for case-sensitive platforms
   return type.toLower();
 }
 
@@ -1044,7 +1040,7 @@ QList<IEditorDescriptor::Pointer> EditorRegistry::SortEditors(
 
 void EditorRegistry::SortInternalEditors()
 {
-  qSort(sortedEditorsFromPlugins.begin(), sortedEditorsFromPlugins.end(), CmpEditorDescriptor());
+  std::sort(sortedEditorsFromPlugins.begin(), sortedEditorsFromPlugins.end(), CmpEditorDescriptor());
 }
 
 void EditorRegistry::EditorMap::PutDefault(const QString& key,
@@ -1095,7 +1091,7 @@ QList<FileEditorMapping::Pointer> EditorRegistry::EditorMap::AllMappings()
     resultSet.insert(iter.value());
   }
 
-  return resultSet.toList();
+  return resultSet.values();
 }
 
 QList<FileEditorMapping::Pointer> EditorRegistry::EditorMap::UserMappings()
