@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "tweaklets/berryGuiWidgetsTweaklet.h"
 
@@ -315,7 +311,7 @@ void PerspectiveHelper::AddPart(LayoutPart::Pointer part)
   }
 
   // If there is no placeholder do a simple add. Otherwise, replace the
-  // placeholder if its not a pattern matching placholder
+  // placeholder if its not a pattern matching placeholder
   if (placeholder == 0)
   {
     part->Reparent(mainLayout->GetParent());
@@ -1153,8 +1149,8 @@ LayoutPart::Pointer PerspectiveHelper::FindPart(const QString& id,
     else if (part->IsPlaceHolder()
              && part.Cast<PartPlaceholder>()->HasWildCard())
     {
-      QRegExp re(id, Qt::CaseInsensitive);
-      if (re.exactMatch(part->GetID()))
+      QRegularExpression re(QString("^%1$").arg(id), QRegularExpression::CaseInsensitiveOption);
+      if (re.match(part->GetID()).hasMatch())
       {
         matchingParts.push_back(MatchingPart(part->GetID(), "", part));
       }
@@ -1233,11 +1229,11 @@ LayoutPart::Pointer PerspectiveHelper::FindPart(const QString& primaryId,
         return part;
       }
       // check for partial matching pair
-      QRegExp pre(phPrimaryId, Qt::CaseInsensitive);
-      if (pre.exactMatch(primaryId))
+      QRegularExpression pre(QString("^%1$").arg(phPrimaryId), QRegularExpression::CaseInsensitiveOption);
+      if (pre.match(primaryId).hasMatch())
       {
-        QRegExp sre(phSecondaryId, Qt::CaseInsensitive);
-        if (sre.exactMatch(secondaryId))
+        QRegularExpression sre(QString("^%1$").arg(phSecondaryId), QRegularExpression::CaseInsensitiveOption);
+        if (sre.match(secondaryId).hasMatch())
         {
           matchingParts.push_back(MatchingPart(phPrimaryId, phSecondaryId, part));
         }
