@@ -27,7 +27,7 @@ class BERRY_UI_QT QtControlWidget : public QFrame
 
 public:
 
-  QtControlWidget(QWidget* parent, Shell* shell, Qt::WindowFlags f = nullptr);
+  QtControlWidget(QWidget* parent, Shell* shell, Qt::WindowFlags f = {});
 
   ~QtControlWidget() override;
 
