@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
-BlueBerry Platform
+The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #include "tweaklets/berryGuiWidgetsTweaklet.h"
 #include "tweaklets/berryWorkbenchTweaklet.h"
@@ -653,6 +649,25 @@ IWorkbench* WorkbenchWindow::GetWorkbench() const
   return PlatformUI::GetWorkbench();
 }
 
+QList<QToolBar*> WorkbenchWindow::GetToolBars() const
+{
+  QList<QToolBar*> result;
+
+  if (auto shell = this->GetShell(); shell.IsNotNull())
+  {
+    if (const auto* mainWindow = qobject_cast<QMainWindow*>(shell->GetControl()); mainWindow != nullptr)
+    {
+      for (auto child : mainWindow->children())
+      {
+        if (auto toolBar = qobject_cast<QToolBar*>(child); toolBar != nullptr)
+          result.append(toolBar);
+      }
+    }
+  }
+
+  return result;
+}
+
 IPartService* WorkbenchWindow::GetPartService()
 {
   return &partService;
@@ -856,9 +871,12 @@ bool WorkbenchWindow::RestoreState(IMemento::Pointer memento,
     //      public void runWithException() {
     if (!shellBounds.intersects(displayBounds))
     {
+      // Center on default screen
       QRect clientArea(Tweaklets::Get(GuiWidgetsTweaklet::KEY)->GetAvailableScreenSize());
-      shellBounds.setX(clientArea.x());
-      shellBounds.setY(clientArea.y());
+      shellBounds.setX(clientArea.width() * 0.05);
+      shellBounds.setY(clientArea.height() * 0.05);
+      shellBounds.setWidth(clientArea.width() * 0.9);
+      shellBounds.setHeight(clientArea.height() * 0.9);
     }
     GetShell()->SetBounds(shellBounds);
     //      }});
@@ -1063,7 +1081,7 @@ bool WorkbenchWindow::RestoreState(IMemento::Pointer memento,
   //      }
   //
   //    } else {
-  //      // For older workbenchs
+  //      // For older workbenches
   //      coolBarMem = memento
   //          .getChild(IWorkbenchConstants.TAG_TOOLBAR_LAYOUT);
   //      if (coolBarMem != null) {
