@@ -132,6 +132,8 @@ public:
 
   IWorkbench* GetWorkbench() const override;
 
+  QList<QToolBar*> GetToolBars() const override;
+
   IPartService* GetPartService() override;
 
   ISelectionService* GetSelectionService() const override;
@@ -182,7 +184,7 @@ public:
   /**
    * Called when this window is about to be closed.
    *
-   * Subclasses may overide to add code that returns <code>false</code> to
+   * Subclasses may override to add code that returns <code>false</code> to
    * prevent closing under certain conditions.
    */
   virtual bool OkToClose();
