@@ -1,22 +1,18 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef MITKDATATREENODESELECTION_H_
-#define MITKDATATREENODESELECTION_H_
+#ifndef mitkDataNodeSelection_h
+#define mitkDataNodeSelection_h
 
 #include <berryIStructuredSelection.h>
 #include <mitkDataNode.h>
@@ -39,13 +35,13 @@ public:
   DataNodeSelection(DataNode::Pointer node);
   DataNodeSelection(const std::vector<DataNode::Pointer>& nodes);
 
-  virtual Object::Pointer GetFirstElement() const override;
-  virtual iterator Begin() const override;
-  virtual iterator End() const override;
+  Object::Pointer GetFirstElement() const override;
+  iterator Begin() const override;
+  iterator End() const override;
 
-  virtual int Size() const override;
+  int Size() const override;
 
-  virtual ContainerType::Pointer ToVector() const override;
+  ContainerType::Pointer ToVector() const override;
 
   std::list<mitk::DataNode::Pointer> GetSelectedDataNodes() const;
 
@@ -64,4 +60,4 @@ protected:
 }
 
 
-#endif /* MITKDATATREENODESELECTION_H_ */
+#endif
