@@ -126,7 +126,7 @@ protected:
    * This implementation calls mitk::IRenderingManager::ForceImmediateUpdate() on the rendering
    * manager interface returned by GetRenderingManager();
    *
-   * \param requestType The type of render windows for which an immedate update is forced.
+   * \param requestType The type of render windows for which an immediate update is forced.
    *
    * \see mitk::IRenderWindowPart::ForceImmediateUpdate
    */
@@ -134,12 +134,12 @@ protected:
 
   /**
    * Get the time navigation controller for this editor.
-   * This implementation returns the SliceNavigationController returned by the mitk::IRenderingManager::GetTimeNavigationController()
+   * This implementation returns the TimeNavigationController returned by the mitk::IRenderingManager::GetTimeNavigationController()
    * method of the interface implementation returned by GetRenderingManager().
    *
    * \see mitk::IRenderingManager::GetTimeNavigationController
    */
-  mitk::SliceNavigationController* GetTimeNavigationController() const override;
+  mitk::TimeNavigationController* GetTimeNavigationController() const override;
 
   /** \see berry::IEditorPart::DoSave */
   void DoSave() override;
