@@ -31,6 +31,7 @@ found in the LICENSE file.
 #include <mitkMAPAlgorithmInfoSelection.h>
 #include <mitkRegistrationHelper.h>
 #include <mitkResultNodeGenerationHelper.h>
+#include <mitkMultiLabelPredicateHelper.h>
 
 // Qmitk
 #include "QmitkMatchPointFrameCorrection.h"
@@ -62,7 +63,6 @@ QmitkMatchPointFrameCorrection::QmitkMatchPointFrameCorrection()
   : m_Parent(nullptr), m_LoadedDLLHandle(nullptr), m_LoadedAlgorithm(nullptr), m_CanLoadAlgorithm(false), m_Working(false)
 {
   m_spSelectedTargetData = nullptr;
-  m_spSelectedTargetMaskData = nullptr;
 }
 
 QmitkMatchPointFrameCorrection::~QmitkMatchPointFrameCorrection()
@@ -198,6 +198,8 @@ void QmitkMatchPointFrameCorrection::CreateQtPartControl(QWidget* parent)
   this->m_Controls.maskNodeSelector->SetPopUpTitel("Select target mask.");
   this->m_Controls.maskNodeSelector->SetPopUpHint("Select a target mask (mask of the target/first frame).");
 
+  m_Controls.maskLabelSelector->SetHighlightingActivated(true);
+
   m_Controls.m_tabs->setCurrentIndex(0);
 
   m_Controls.m_mapperSettings->AllowSampling(false);
@@ -226,7 +228,6 @@ void QmitkMatchPointFrameCorrection::CreateQtPartControl(QWidget* parent)
 void QmitkMatchPointFrameCorrection::ConfigureNodeSelectorPredicates()
 {
   auto isImage = mitk::MITKRegistrationHelper::ImageNodePredicate();
-  mitk::NodePredicateBase::Pointer maskDimensionPredicate = mitk::NodePredicateOr::New(mitk::NodePredicateDimension::New(3), mitk::NodePredicateDimension::New(4)).GetPointer();
   mitk::NodePredicateDimension::Pointer imageDimensionPredicate = mitk::NodePredicateDimension::New(4);
 
   m_Controls.imageNodeSelector->setEnabled(m_LoadedAlgorithm.IsNotNull());
@@ -234,13 +235,7 @@ void QmitkMatchPointFrameCorrection::ConfigureNodeSelectorPredicates()
 
   m_Controls.imageNodeSelector->SetNodePredicate(mitk::NodePredicateAnd::New(isImage, imageDimensionPredicate));
 
-  mitk::NodePredicateAnd::Pointer maskPredicate = mitk::NodePredicateAnd::New(mitk::MITKRegistrationHelper::MaskNodePredicate(), maskDimensionPredicate);
-  if (m_spSelectedTargetData != nullptr)
-  {
-    auto hasSameGeometry = mitk::NodePredicateGeometry::New(m_spSelectedTargetData->GetGeometry());
-    hasSameGeometry->SetCheckPrecision(1e-10);
-    maskPredicate = mitk::NodePredicateAnd::New(maskPredicate, hasSameGeometry);
-  }
+  auto maskPredicate = (m_spSelectedTargetData.IsNull()) ? mitk::GetMultiLabelSegmentationPredicate() : mitk::GetMultiLabelSegmentationPredicate(m_spSelectedTargetData->GetGeometry());
 
   m_Controls.maskNodeSelector->SetNodePredicate(maskPredicate);
 }
@@ -253,7 +248,6 @@ void QmitkMatchPointFrameCorrection::CheckInputs()
   m_spSelectedTargetData = nullptr;
 
   m_spSelectedTargetMaskNode = nullptr;
-  m_spSelectedTargetMaskData = nullptr;
 
   if (m_LoadedAlgorithm.IsNull())
   {
@@ -268,10 +262,10 @@ void QmitkMatchPointFrameCorrection::CheckInputs()
       m_spSelectedTargetData = m_spSelectedTargetNode->GetData();
     }
 
-    m_spSelectedTargetMaskNode = m_Controls.maskNodeSelector->GetSelectedNode();
-    if (m_spSelectedTargetMaskNode.IsNotNull())
+    if (m_Controls.maskNodeSelector->GetSelectedNode() != m_spSelectedTargetMaskNode)
     {
-      m_spSelectedTargetMaskData = dynamic_cast<mitk::Image*>(m_spSelectedTargetMaskNode->GetData());
+      m_Controls.maskLabelSelector->SetMultiLabelNode(m_Controls.maskNodeSelector->GetSelectedNode());
+      m_spSelectedTargetMaskNode = m_Controls.maskNodeSelector->GetSelectedNode();
     }
   }
 
@@ -337,6 +331,8 @@ void QmitkMatchPointFrameCorrection::ConfigureRegistrationControls()
   m_Controls.imageNodeSelector->setEnabled(!m_Working);
   m_Controls.maskNodeSelector->setEnabled(!m_Working);
 
+  m_Controls.maskLabelSelector->setVisible(m_spSelectedTargetMaskNode.IsNotNull());
+
   if (m_LoadedAlgorithm.IsNotNull())
   {
     m_Controls.m_tabSettings->setEnabled(!m_Working);
@@ -350,6 +346,7 @@ void QmitkMatchPointFrameCorrection::ConfigureRegistrationControls()
                                        (m_LoadedAlgorithm.GetPointer());
 
     m_Controls.maskNodeSelector->setVisible(pMaskReg != nullptr);
+    m_Controls.maskLabelSelector->setVisible(m_spSelectedTargetMaskNode.IsNotNull() && pMaskReg != nullptr);
     m_Controls.label_TargetMask->setVisible(pMaskReg != nullptr);
     if (!pMaskReg)
     {
@@ -531,10 +528,11 @@ void QmitkMatchPointFrameCorrection::OnStartRegBtnPushed()
   pJob->m_TargetDataUID = mitk::EnsureUID(this->m_spSelectedTargetNode->GetData());
   pJob->m_IgnoreList = this->GenerateIgnoreList();
 
-  if (m_spSelectedTargetMaskData.IsNotNull())
+  auto targetMask = m_Controls.maskLabelSelector->CreateSelectedLabelMask();
+  if (targetMask.IsNotNull())
   {
-    pJob->m_spTargetMask = m_spSelectedTargetMaskData;
-    pJob->m_TargetMaskDataUID = mitk::EnsureUID(this->m_spSelectedTargetMaskNode->GetData());
+    pJob->m_spTargetMask = mitk::SelectImageByTimeStep(targetMask, 0);
+    pJob->m_TargetMaskDataUID = mitk::EnsureUID(this->m_spSelectedTargetMaskNode->GetData()) + "#" + std::to_string(m_Controls.maskLabelSelector->GetSelectedLabels().front());
   }
 
   pJob->m_MappedName = m_Controls.m_leRegJobName->text().toStdString();
