@@ -1,18 +1,14 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 #ifndef QmitkAnimationItemDelegate_h
 #define QmitkAnimationItemDelegate_h
@@ -25,7 +21,7 @@ class QmitkAnimationItemDelegate : public QStyledItemDelegate
 
 public:
   explicit QmitkAnimationItemDelegate(QObject* parent = nullptr);
-  ~QmitkAnimationItemDelegate();
+  ~QmitkAnimationItemDelegate() override;
 
   void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const override;
 };
