@@ -11,6 +11,7 @@ found in the LICENSE file.
 ============================================================================*/
 
 #include "QmitkPixelValueView.h"
+#include <QmitkStyleManager.h>
 
 #include <mitkNodePredicateAnd.h>
 #include <mitkNodePredicateDataType.h>
@@ -20,8 +21,25 @@ found in the LICENSE file.
 #include <mitkPixelTypeMultiplex.h>
 #include <mitkImagePixelReadAccessor.h>
 
+#include <QClipboard>
+
 #include <ui_QmitkPixelValueView.h>
 
+#include <regex>
+
+namespace
+{
+  void CopyCoordsToClipboard(const QLineEdit* x, const QLineEdit* y, const QLineEdit* z)
+  {
+    auto text = QStringList() << x->text() << y->text();
+
+    if (const auto zText = z->text(); !zText.isEmpty())
+      text << zText;
+
+    QApplication::clipboard()->setText(text.join(", "));
+  }
+}
+
 const std::string QmitkPixelValueView::VIEW_ID = "org.mitk.views.pixelvalue";
 
 QmitkPixelValueView::QmitkPixelValueView(QObject*)
@@ -37,6 +55,18 @@ void QmitkPixelValueView::CreateQtPartControl(QWidget* parent)
 {
   m_Ui->setupUi(parent);
 
+  auto clipboardIcon = QmitkStyleManager::ThemeIcon(QLatin1String(":/Qmitk/clipboard.svg"));
+  m_Ui->copyIndexCoordButton->setIcon(clipboardIcon);
+  m_Ui->copyWorldCoordButton->setIcon(clipboardIcon);
+
+  connect(m_Ui->copyIndexCoordButton, &QToolButton::clicked, [this]() {
+    CopyCoordsToClipboard(m_Ui->indexXLineEdit, m_Ui->indexYLineEdit, m_Ui->indexZLineEdit);
+  });
+
+  connect(m_Ui->copyWorldCoordButton, &QToolButton::clicked, [this]() {
+    CopyCoordsToClipboard(m_Ui->worldXLineEdit, m_Ui->worldYLineEdit, m_Ui->worldZLineEdit);
+  });
+
   this->m_SliceNavigationListener.RenderWindowPartActivated(this->GetRenderWindowPart());
   connect(&m_SliceNavigationListener, &QmitkSliceNavigationListener::SelectedPositionChanged, this, &QmitkPixelValueView::OnSelectedPositionChanged);
   connect(&m_SliceNavigationListener, &QmitkSliceNavigationListener::SelectedTimePointChanged, this, &QmitkPixelValueView::OnSelectedTimePointChanged);
@@ -80,7 +110,7 @@ void QmitkPixelValueView::Update()
   const auto timePoint = m_SliceNavigationListener.GetCurrentSelectedTimePoint();
   
   auto isImage = mitk::TNodePredicateDataType<mitk::Image>::New();
-  auto isSegmentation = mitk::NodePredicateDataType::New("LabelSetImage");
+  auto isSegmentation = mitk::NodePredicateDataType::New("MultiLabelSegmentation");
 
   auto predicate = mitk::NodePredicateAnd::New();
   predicate->AddPredicate(mitk::NodePredicateNot::New(isSegmentation));
@@ -146,42 +176,43 @@ void QmitkPixelValueView::Update()
     if (pixelType == itk::IOPixelEnum::RGB || pixelType == itk::IOPixelEnum::RGBA)
     {
       m_Ui->pixelValueLineEdit->setText(QString::fromStdString(mitk::ConvertCompositePixelValueToString(image, index)));
-      return;
     }
-
-    if (pixelType == itk::IOPixelEnum::DIFFUSIONTENSOR3D || pixelType == itk::IOPixelEnum::SYMMETRICSECONDRANKTENSOR)
+    else if (pixelType == itk::IOPixelEnum::DIFFUSIONTENSOR3D || pixelType == itk::IOPixelEnum::SYMMETRICSECONDRANKTENSOR)
     {
       m_Ui->pixelValueLineEdit->setText(QStringLiteral("See ODF Details view."));
-      return;
-    }
-
-    mitk::ScalarType pixelValue = 0.0;
-
-    mitkPixelTypeMultiplex5(
-      mitk::FastSinglePixelAccess,
-      image->GetChannelDescriptor().GetPixelType(),
-      image,
-      image->GetVolumeData(image->GetTimeGeometry()->TimePointToTimeStep(timePoint)),
-      index,
-      pixelValue,
-      component);
-
-    std::ostringstream stream;
-    stream.imbue(std::locale::classic());
-    stream.precision(2);
-
-    if (fabs(pixelValue) > 1000000 || fabs(pixelValue) < 0.01)
-    {
-      stream << std::scientific;
     }
     else
     {
-      stream << std::fixed;
+      mitk::ScalarType pixelValue = 0.0;
+
+      mitkPixelTypeMultiplex5(
+        mitk::FastSinglePixelAccess,
+        image->GetChannelDescriptor().GetPixelType(),
+        image,
+        image->GetVolumeData(image->GetTimeGeometry()->TimePointToTimeStep(timePoint)),
+        index,
+        pixelValue,
+        component);
+
+      std::ostringstream stream;
+      stream.imbue(std::locale::classic());
+      stream.precision(2);
+
+      if (fabs(pixelValue) > 1000000 || fabs(pixelValue) < 0.01)
+      {
+        stream << std::scientific;
+      }
+      else
+      {
+        stream << std::fixed;
+      }
+
+      stream << pixelValue;
+
+      m_Ui->pixelValueLineEdit->setText(QString::fromStdString(stream.str()));
     }
 
-    stream << pixelValue;
-
-    m_Ui->pixelValueLineEdit->setText(QString::fromStdString(stream.str()));
+    this->UpdateCoords(image, index, position);
   }
   else
   {
@@ -189,12 +220,104 @@ void QmitkPixelValueView::Update()
   }
 }
 
+void QmitkPixelValueView::UpdateCoords(const mitk::Image* image, const itk::Index<3>& index, const mitk::Point3D& position)
+{
+  const auto dimension = image->GetDimension();
+
+  this->UpdateIndexCoord(index, dimension);
+  this->UpdateWorldCoord(position, dimension);
+
+  const auto geometry = image->GetTimeGeometry();
+
+  this->UpdateTimeStep(geometry);
+}
+
+void QmitkPixelValueView::UpdateIndexCoord(const itk::Index<3>& index, unsigned int dimension)
+{
+  m_Ui->indexXLineEdit->setText(QString::number(index[0]));
+  m_Ui->indexYLineEdit->setText(QString::number(index[1]));
+
+  if (dimension > 2)
+  {
+    m_Ui->indexZLineEdit->setText(QString::number(index[2]));
+  }
+  else
+  {
+    m_Ui->indexZLineEdit->clear();
+  }
+
+  m_Ui->copyIndexCoordButton->setEnabled(true);
+}
+
+void QmitkPixelValueView::UpdateWorldCoord(const mitk::Point3D& position, unsigned int dimension)
+{
+  m_Ui->worldXLineEdit->setText(QString::number(position[0], 'f', 2));
+  m_Ui->worldYLineEdit->setText(QString::number(position[1], 'f', 2));
+
+  if (dimension > 2)
+  {
+    m_Ui->worldZLineEdit->setText(QString::number(position[2], 'f', 2));
+  }
+  else
+  {
+    m_Ui->worldZLineEdit->clear();
+  }
+
+  m_Ui->copyWorldCoordButton->setEnabled(true);
+}
+
+void QmitkPixelValueView::UpdateTimeStep(const mitk::TimeGeometry* geometry)
+{
+  const auto* renderingManager = mitk::RenderingManager::GetInstance();
+  const auto* timeNavController = renderingManager->GetTimeNavigationController();
+  const auto timePoint = timeNavController->GetSelectedTimePoint();
+
+  if (geometry->CountTimeSteps() <= 1 || !geometry->IsValidTimePoint(timePoint))
+  {
+    this->ShowTimeStep(false);
+    return;
+  }
+
+  const auto timeStep = geometry->TimePointToTimeStep(timePoint);
+  m_Ui->timeStepLineEdit->setText(QString::number(timeStep));
+
+  this->ShowTimeStep(true);
+}
+
+void QmitkPixelValueView::ShowTimeStep(bool show)
+{
+  m_Ui->timeStepLabel->setVisible(show);
+  m_Ui->timeStepLineEdit->setVisible(show);
+}
+
 void QmitkPixelValueView::Clear()
 {
   m_Ui->imageNameLineEdit->clear();
   m_Ui->pixelValueLineEdit->clear();
+
+  this->ClearCoords();
+}
+
+void QmitkPixelValueView::ClearCoords()
+{
+  m_Ui->indexXLineEdit->clear();
+  m_Ui->indexYLineEdit->clear();
+  m_Ui->indexZLineEdit->clear();
+
+  m_Ui->copyIndexCoordButton->setEnabled(false);
+
+  m_Ui->worldXLineEdit->clear();
+  m_Ui->worldYLineEdit->clear();
+  m_Ui->worldZLineEdit->clear();
+
+  m_Ui->copyWorldCoordButton->setEnabled(false);
+
+  m_Ui->timeStepLineEdit->clear();
+
+  this->ShowTimeStep(false);
 }
 
 void QmitkPixelValueView::SetFocus()
 {
+  m_Ui->pixelValueLineEdit->setFocus();
 }
