@@ -16,8 +16,10 @@ found in the LICENSE file.
 #include "ui_QmitkSegmentationViewControls.h"
 
 #include <QmitkAbstractView.h>
+#include <QmitkButtonOverlayWidget.h>
 #include <mitkITKEventObserverGuard.h>
 #include <mitkIRenderWindowPartListener.h>
+#include <mitkLabelSetImageHelper.h>
 
 /**
 * @brief The segmentation view provides a set of tool to use different segmentation algorithms.
@@ -75,24 +77,25 @@ private Q_SLOTS:
 
   void OnCurrentLabelSelectionChanged(QmitkMultiLabelManager::LabelValueVectorType labels);
 
-  void OnGoToLabel(mitk::LabelSetImage::LabelValueType label, const mitk::Point3D&);
+  void OnGoToLabel(mitk::MultiLabelSegmentation::LabelValueType label, const mitk::Point3D&);
   void OnLabelRenameRequested(mitk::Label* label, bool rename, bool& canceled) const;
 
-  void OnLabelAdded(mitk::LabelSetImage::LabelValueType labelValue);
-  void OnLabelRemoved(mitk::LabelSetImage::LabelValueType labelValue);
-  void OnGroupRemoved(mitk::LabelSetImage::GroupIndexType groupIndex);
+  void OnLabelAdded(mitk::MultiLabelSegmentation::LabelValueType labelValue);
+  void OnLabelRemoved(mitk::MultiLabelSegmentation::LabelValueType labelValue);
+  void OnGroupRemoved(mitk::MultiLabelSegmentation::GroupIndexType groupIndex);
 
 private:
 
   using Self = QmitkSegmentationView;
 
-  mitk::LabelSetImage* GetWorkingImage();
+  mitk::MultiLabelSegmentation* GetWorkingImage();
   void AddObserversToWorkingImage();
   void RemoveObserversFromWorkingImage();
 
   void CreateQtPartControl(QWidget* parent) override;
 
   void SetFocus() override {}
+
   /**
   * @brief Enable or disable the SegmentationInteractor.
   *
@@ -100,12 +103,16 @@ private:
   * If the active tool is valid, the SegmentationInteractor is enabled
   * to listen to 'SegmentationInteractionEvent's.
   */
-  void ActiveToolChanged();
+  void OnActiveToolChanged();
+
+  void OnActiveWorkingLabelSelectionChanged();
 
   void RenderWindowPartActivated(mitk::IRenderWindowPart* renderWindowPart) override;
   void RenderWindowPartDeactivated(mitk::IRenderWindowPart* renderWindowPart) override;
   void RenderWindowPartInputChanged(mitk::IRenderWindowPart* renderWindowPart) override;
 
+  void UpdateLabelSuggestions();
+
   void OnPreferencesChanged(const mitk::IPreferences* prefs) override;
 
   void NodeAdded(const mitk::DataNode* node) override;
@@ -130,19 +137,18 @@ private:
 
   void OnSelectionChanged(berry::IWorkbenchPart::Pointer part, const QList<mitk::DataNode::Pointer> &nodes) override;
 
-  void ResetMouseCursor();
-
-  void SetMouseCursor(const us::ModuleResource&, int hotspotX, int hotspotY);
-
   void UpdateGUI();
 
+  void CheckForReferenceVisibilityWarnings() const;
+  void CheckForToolViolations() const;
+
+  void UpdateControlsOnLabelChanges();
+
   void ValidateSelectionInput();
 
-  void UpdateWarningLabel(QString text);
-
   std::string GetDefaultLabelSetPreset() const;
 
-  mitk::LabelSetImage* GetCurrentSegmentation() const;
+  mitk::MultiLabelSegmentation* GetCurrentSegmentation() const;
 
   QWidget* m_Parent;
 
@@ -175,6 +181,11 @@ private:
   mitk::ITKEventObserverGuard m_LabelAddedObserver;
   mitk::ITKEventObserverGuard m_LabelRemovedObserver;
   mitk::ITKEventObserverGuard m_GroupRemovedObserver;
+
+  mitk::LabelSuggestionHelper::Pointer m_LabelSuggestionHelper;
+
+  QmitkButtonOverlayWidget* m_GeometryViolationOverlay;
+  QmitkButtonOverlayWidget* m_VisibleSegViolationOverlay;
 };
 
 #endif
