@@ -1,20 +1,16 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
-#ifndef MITKPLUGINACTIVATOR_H
-#define MITKPLUGINACTIVATOR_H
+============================================================================*/
+#ifndef mitkPluginActivator_h
+#define mitkPluginActivator_h
 
 // Parent classes
 #include <berryAbstractUICTKPlugin.h>
@@ -24,15 +20,13 @@ namespace mitk
   class PluginActivator : public berry::AbstractUICTKPlugin
   {
     Q_OBJECT
-#if QT_VERSION >= QT_VERSION_CHECK(5, 0, 0)
     Q_PLUGIN_METADATA(IID "org_mitk_gui_qt_segmentation")
-#endif
     Q_INTERFACES(ctkPluginActivator)
 
   public:
 
     PluginActivator();
-    ~PluginActivator();
+    ~PluginActivator() override;
 
     void start(ctkPluginContext *context) override;
     void stop(ctkPluginContext *context) override;
