@@ -1,24 +1,18 @@
-/*===================================================================
+/*============================================================================
 
 The Medical Imaging Interaction Toolkit (MITK)
 
-Copyright (c) German Cancer Research Center,
-Division of Medical and Biological Informatics.
+Copyright (c) German Cancer Research Center (DKFZ)
 All rights reserved.
 
-This software is distributed WITHOUT ANY WARRANTY; without
-even the implied warranty of MERCHANTABILITY or FITNESS FOR
-A PARTICULAR PURPOSE.
+Use of this source code is governed by a 3-clause BSD license that can be
+found in the LICENSE file.
 
-See LICENSE.txt or http://www.mitk.org for details.
-
-===================================================================*/
+============================================================================*/
 
 
-#ifndef QMITKXNATSESSIONMANAGER_H_
-#define QMITKXNATSESSIONMANAGER_H_
-
-#include <berryIPreferencesService.h>
+#ifndef QmitkXnatSessionManager_h
+#define QmitkXnatSessionManager_h
 
 #include "ctkXnatLoginProfile.h"
 
@@ -50,4 +44,4 @@ private:
 
 };
 
-#endif /*QMITKXNATSESSIONMANAGER_H_*/
+#endif
